%------------------------------------------------------------------------
% Routine         : bpplot.m
%
% Description     : Plots the resulting beampattern as calculated by beampat.
%		    The code is extracted from an old version of beampat.
%
% Language        : Matlab 4.1
% Written by      : SH VMS, VEB & FT IBT.
%  
% Version no.     : 3.0    08.08.93
% Version no.     : 3.1 EI 15.10.93 Added call to plottext
%                 : 3.2 FT 15.02.94 ylabel for annular transducer 
%                 : 3.3 SH 12.04.95 Added flagg(4)=4 and
%                                   excitation(2:4) now in polar coordinates
%                   3.4 LO 14.12.95 Normalized beamprofile plotted,
%                                   and max(rms) before normalization 
%                                   is printed 
%                   3.5 SH 29.05.97 Matlab 5: removed end at end
%                      
%
% Called by       : bporg
% Routines called : xyz2rhp, plottext, weightxt, akser, focustxt
% -----------------------------------------------------------------------

function bpplot(plotfig,transducer,excitation,option,observasjon,flagg,rms);


%          DEFINITION OF PARAMETERS
%------------------------------------------------------------------------

osc=excitation(9);
Weig_numb=excitation(10);
pflag = excitation(13); % pflag = 1 If a user-defined pulse is used

ElF_r = excitation(2);
ElF_theta = excitation(3);
ElF_phi = excitation(4);

if pflag == 0, 
  pulse_string = [num2str(osc),' periods, ',weightxt(Weig_numb)];
else
  pulse_string = ['User-defined pulse'];
end
  	

% VEB 15/2-93
figure(plotfig);
% VEB 15/2-93

% SH 17.08.2007: needs a statement to restart figure without deleting menus


abscissa=akser(option,observasjon);

%
% FT 29/7-93
% Selects different linetypes if several plots are drawn in
% the same figure by using hold on.
%-----------------------------------------------------------------

currentline = get(line,'LineStyle');
hol=get(gca,'NextPlot');
if (hol(1)=='a')  	% hold on
   if length(currentline) == 1
	if (currentline == '-')
   		set(gca,'DefaultLineLineStyle','--');
	else
   		set(gca,'DefaultLineLineStyle','-');
	end
   else
	if (currentline == '--')
   		set(gca,'DefaultLineLineStyle','-.');
	else
   		set(gca,'DefaultLineLineStyle',':');
 	end
   end
else
   set(gca,'DefaultLineLineStyle','-');
end

%**********************************************************************
% 	PLOTTING
%------------------------------------------------------------------------
rmsmax=max(rms);
rms=rms-rmsmax;
plot(abscissa,rms,get(line,'Linestyle'));
title('Beampattern (delays set for steering to fixed point, source moves)')
grid on;
xlabel([pulse_string,', ',quanttxt(excitation),', ',...
	num2str(abstxt(option,observasjon))]);
if flagg(2)==1   	% Rectangular/oval transucer
  if flagg(4) ~= 4
   ylabel(['[dB], ',focustxt(ElF_r),', steered angles = (',...
	num2str((180/pi)*ElF_phi),', ',...
	num2str((180/pi)*ElF_theta),') degrees']);  
  else
   ylabel(['[dB], ',focustxt(ElF_r),', steered sines = (',...
	num2str(sin(ElF_phi)),', ',...
	num2str(sin(ElF_theta)),')']);
  end    
elseif flagg(2)==3			% Annular transducer
  ylabel(['[dB], ',focustxt(ElF_r)]);
end
axis('normal');
plottext(flagg,excitation,transducer,hol,rmsmax);







