%------------------------------------------------------------------------
% Routine     : phaseu
%
% Description : Adds a random phase delay to all points on the 
%                   transducer. The random delays are added to the
%                   previously calculated electronic focusing delays.
%
% Language    : MATLAB 4.1
% Written by  : Frode Teigen (IBT)
%
% Version no. : 1.0 FT 20.04.94 First Version
%               27.09.2006 SH renamed from phase.m to phaseu.m to avoid
%               conflict with toolbox/ident/idobsolete/phase.m
%
% Called by   : focus
% Calling     : none
%------------------------------------------------------------------------

function delays = phaseu(excitation,transducer,c,elem_pts,delays)

clear global phase_err
global phase_err phase_err_ud

Npts   = length(elem_pts(1,:));
f = excitation(1);
lambda = c/f;

%
% find phase center of each element by averaging over all points in element:
%

if excitation(7)==1
  stand = excitation(8)/f;
  rand_delay = randn(1,Npts)*stand;
  delays = delays + rand_delay;
elseif excitation(7)==2
  pointsprmm = 10/(lambda*1e3);
  simlengthmm = transducer(1)*1e3;
  corrlengthmm = 7.9;
  totstdns = 43;
  randn('seed',excitation(8));
  
  m = round((corrlengthmm/2)*pointsprmm);
  phi = (0.5)^(1/m);
  sigma = totstdns*(1 - phi^2)^.5;
  phase_err(2,:) = -simlengthmm/2*1e-3:1e-3/pointsprmm:...
      simlengthmm/2*1e-3;
  w = randn(1,size(phase_err,2))*sigma;
  phase_err(1,1) = w(1)*1e-9;
  for n = 2:length(w)
    phase_err(1,n) = phi*phase_err(1,n-1) + w(n)*1e-9;
  end
  
  %lag matrise phase_err rad 1 : tidsfeil
  %                      rad 2 : x-verdi
 for n=1:Npts
   indtemp = find(abs(phase_err(2,:) - elem_pts(1,n))==...
	min(abs(phase_err(2,:) - elem_pts(1,n))));
    delays(n) = delays(n) + phase_err(1,indtemp(1));
  end
elseif excitation(7)==3
  phase_err(1,:) = phase_err_ud(1,:)*1e-9;
  phase_err(2,:) = phase_err_ud(2,:)*1e-3;
  for n=1:Npts
    indtemp = find(abs(phase_err(2,:) - elem_pts(1,n))==...
	min(abs(phase_err(2,:) - elem_pts(1,n))));
    delays(n) = delays(n) + phase_err(1,indtemp(1));
  end
end









