%------------------------------------------------------------------------
% Routine     : pulse.m
%
% Description : M-file for computing pulse shape as a
%		function of time rel. center of pulse (x)
%		pulse length (plen in seconds)
%		and pulse shape (Weig_numb: 0 = rectangular, 1 = cosine)
%
% Language    : Matlab 4.0
% Written by  : Sverre Holm (Vingmed Sound A/S)
%
% Version no. : 1.0 SH 31.10.91 First Version
%               2.0 FT 28.09.94 Included attenuation
%               3.0 LO 14.12.95 flagg removed from call
%
% Called by   : beampat
% Calling     : 
%------------------------------------------------------------------------
%
	function [y,CGp] = pulse(xx,plen,Weig_numb,attenuation)
	
	[m,n] = size(xx);
	x = xx(:);
        
        if max(size(attenuation))>1
	  a = attenuation(:);
	else
	  a = ones(size(x))*attenuation;
	end
	y = zeros(size(x));

%
%  check for pulse on or off
%
	i = find(abs(xx) <= plen/2);
 	if (Weig_numb == 0)
% 
% rectangular pulse
%
		y(i) = ones(size(i)).*a(i);
%
% find coherent gain
%
		CGp = 1;
	else 		
% 
% cosine shape
%	
		y(i) = cos(pi*x(i)/plen).*a(i);
		xxx = -100:100;
		yyy = cos(pi*xxx/200);
		CGp = sum(yyy)/201;
	end
	y = reshape(y,m,n);
        clear a
	return
