%------------------------------------------------------------------------ 
% Routine     : thinning.m 
% Description : Routine for manual array thinning  
% 
% Language    : Matlab 4.2 
% Written by  : Jan Ove Erstad , IfI 
% 
% Version no. : 1.0 JOE 29.03.94 First version 
%		1.1 JOE 19.04.94 Included random thinning  
%		1.2 JOE 23.04.94 Thinned elem_pts(4,:) set to negative. 
%		1.3 JOE 19.05.94 Enable vector argument and restoring array 
%		1.5 JOE 16.08.94 Undelete single elements  
%		1.6 JOE 21.10.94 Corrected restore function, included  
%		                 mouse-button thin and symmetric thinning. 
%		1.7 JOE 10.11.94 Included geometric placement of elements  
%		1.8 JOE 03.04.95 Changed to give input in command window  
%		1.9 BJE 25.04.95 removed ConfigOrigHandle from functioncall 
%
%
% Called by   : usimcnf 
% Calling     : viewtrsd 
%------------------------------------------------------------------------ 
function [el_p] = thinning(transducer,flagg,elem_pts,config); 
% 
fid=1; 
figure(config); 			% assigning config window 
viewtrsd(transducer,elem_pts,flagg); 
done   = 0; 
el_p   = elem_pts; 
flagS  = 1; 				% Symmetry flag 
flagtxt= 'ON '; 
N      = max(size(el_p)); 		%number of grid positions 
while ~done 				% thinning loop 
  clc 
  disp(' '); 
  disp(' *********************************************** '); 
  disp(' *        Rectangular transducer arrays:       * '); 
  disp(' * Delete area                 :   1           * '); 
  disp(' * Delete row(s)               :   2           * '); 
  disp(' * Delete column(s)            :   3           * '); 
  disp(' * Delete element points       :   4           * '); 
  disp(' * Random thinning/displacement:   5           * '); 
  disp(' *        Circular transducer arrays:          * '); 
  disp(' * Circular point thinning     :   6           * '); 
  disp(' *        Corrections :                        * '); 
  disp(' * Insert deleted elements     :   7           * '); 
  disp(' * Place elems. at new locations:  8           * '); 
  disp(' * Restore entire array        :   9           * '); 
  disp(' * Undo last change            :  10           * '); 
  disp(' *                                             * '); 
  disp([' *      Symmetric thinning    =    ',flagtxt,'         * ']); 
  disp(' * Change symmetry flag?       :   0           * '); 
  disp(' *********************************************** '); 
  disp(' '); 
  comm = input(' Command :  '); 
  if isempty(comm) 
    done = 1; 
  % 
  %  
  elseif (comm == 1) 			%THINNING OF  AREA 
    %------------------ 
    old_pts = el_p; 
    disp(' '); 
    disp('You may delete elements within a rectangular area. Mark lower left'); 
    disp('and upper right element by pushing left button on mouse.'); 
    disp('Symmetric thinning is not implemented in this routine. ');disp(' '); 
    %array dimensions 
    left_el  = min(el_p(1,:)); 		% x-coordinate lower left array corner 
    low_el   = min(el_p(2,:)); 		% y-coordinate lower left array corner 
    rite_el  = max(el_p(1,:)); 		% x-coord. upper right array corner 
    upr_el   = max(el_p(2,:)); 		% y-coord. upper right array corner 
         
    % (linear) element spacings 
    d_col    = (rite_el - left_el)/(max(el_p(4,:))-1); 
    if any(el_p(2,:) ~= 0) 
      d_row    = (upr_el  - low_el)/(max(el_p(5,:))-1);  
    else 
      d_row    = 0.001; 
    end  
     
    disp('Select lower left and upper right corner elements.'); 
    [clo,rlo]= ginput(2); 
    xlo   = clo(1)*1e-03;   xup   = clo(2)*1e-03; 
    ylo   = rlo(1)*1e-03;   yup   = rlo(2)*1e-03; 
     
    if (xlo < (left_el-d_col)) | (xup > (rite_el+d_col)) |... 
	  (ylo < (low_el-d_row)) | (yup > (upr_el+d_row)) 
      disp('Input error! Point is outside the array.'); 
       
    elseif (xlo > xup) | (ylo > yup) 
      disp('Input error! Upper corner is selected below lower corner.');  
    else 
       
      low_col = el_p(4,min(find(((abs(el_p(1,:) - xlo)) < (d_col/2))))); 
      upp_col = el_p(4,max(find(((abs(el_p(1,:) - xup)) < (d_col/2))))); 
      low_row = el_p(5,min(find(((abs(el_p(2,:) - ylo)) < (d_col/2))))); 
      upp_row = el_p(5,max(find(((abs(el_p(2,:) - yup)) < (d_col/2))))); 
       
      cand_col = find((el_p(4,:) >= low_col) & (el_p(4,:) <= upp_col));      
      cand_row = find((el_p(5,:) >= low_row) & (el_p(5,:) <= upp_row)); 
       
      if max(size(cand_col)) < max(size(cand_row)) 
	clent = max(size(cand_col)); 
	cand1 = cand_col; 
	cand2 = cand_row; 
      else 
	clent = max(size(cand_row)); 
	cand1 = cand_row; 
	cand2 = cand_col; 
      end  
       
      if clent < max(size(elem_pts)) 
	for k=1:clent 
	  if any(cand1(k) == cand2) 
	    cut_el = cand1(k); 
	    if el_p(4,cut_el) > 0 
	      el_p(4,cut_el)= -1*el_p(4,cut_el); 
	    end  
	  end  
	end  				% for k=1:cl  
	viewtrsd(transducer,el_p,flagg); 
      else 
	disp('Too many elements chosen!'); 
      end    
    end  				%if (xlo... 
    input('Push a key to continue.'); 
    %---------------------------------------------------------------------- 
  elseif (comm == 2) 			%THINNING OF  LINE/ROWS  
    %--------------------------- 
    old_pts = el_p; 
    % max. dimension in elevation direction (rows) 
    max_rows = max(el_p(5,:)); 
    if max_rows > 1 
      disp(' '); 
      disp(['Symmetric thinning is ',flagtxt,'.']); 
      disp(' '); 
      disp('Choose desired row(s) by pushing left button on mouse.'); 
      disp('Thinning is terminated by pushing middle or right button.'); 
      disp(' '); 
      num = 0; 
      but = 1; 
      dec_el = (max(el_p(2,:))-min(el_p(2,:)))/(max_rows-1); 
      while (but == 1) & (num < max_rows-1) 
	[co,ro,but] = ginput(1); 
	if but == 1   
	  rx   = ro*1e-03; 
	  cut_elem = find(abs(el_p(2,:) - rx) < dec_el/2); 
	  if flagS == 1 
	    row = abs(el_p(5,cut_elem(1))); %row number 
	    % finding the mirror row 
	    if (row ~= max_rows - row +1) 
	      cut_elem = [cut_elem find(el_p(5,:) == (max_rows - row + 1))]; 
	      num = num + 2; 
	    end  
	  else 
	    num    =  num + 1; 
	  end  
 
	  cut_elem = cut_elem(find(el_p(4,cut_elem) >= 0)); 
	  % setting thinned element to negative value 
	  el_p(4,cut_elem)=-1*el_p(4,cut_elem); 
	  viewtrsd(transducer,el_p,flagg); 
	end  				%if but==1 
      end  				%while 
       
      if num >= max_rows - 1 
	disp('No more rows can be thinned!'); 
      end  
    else 
      disp('This is a linear array.Rows cannot be thinned!'); 
      disp('Push a key to continue .'); 
      b = ginput(1); 
      done = 1; 
    end  				%if max_rows > 1 
    input('Push a key to continue.'); 
 
    %------------------------------------------------------------------------- 
  elseif (comm == 3) 			%THINNING OF  COLUMNS  
    %--------------------------- 
    old_pts = el_p; 
    max_col = max(el_p(4,:)); 		% max. dimension in azimuth (columns) 
    disp(' '); 
    disp(['Symmetric thinning is ',flagtxt,'.']); 
    disp(' '); 
    disp('Choose desired column(s) by pushing left button on mouse.'); 
    disp('Thinning is terminated by pushing middle or right button.'); 
    disp(' '); 
    num = 0; 
    but = 1; 
    dec_el = (max(el_p(1,:))-min(el_p(1,:)))/(max_col-1); 
    while (but == 1) & (num < max_col-1) 
      [co,ro,but] = ginput(1); 
      if but == 1   
	cx     = co*1e-03; 
	cut_elem = find(abs(el_p(1,:) - cx) < dec_el/2); %elements in column 
	if flagS == 1 
	  col = abs(el_p(4,cut_elem(1))); %column number 
	  % finding the mirror column 
	  if (col ~= max_col - col +1) 
	    cut_elem = [cut_elem find(el_p(4,:) == (max_col - col + 1))]; 
	    num = num + 2; 
	  end  
	else 
	  num    =  num + 1; 
	end  
	 
	cut_elem = cut_elem(find(el_p(4,cut_elem) >= 0)); 
	% setting thinned element to negative value 
	el_p(4,cut_elem)=-1*el_p(4,cut_elem); 
	viewtrsd(transducer,el_p,flagg); 
      end  				%if but==1 
    end  				%while 
     
    if num >= max_col - 1 
      disp('No more columns can be thinned!'); 
    end  
    input('Push a key to continue.'); 
 
    %------------------------------------------------------------------------- 
  elseif (comm == 4) 			%THINNING OF ELEMENTS  
    %--------------------------- 
    old_pts = el_p; 
    max_col = max(el_p(4,:)); 
    max_rows = max(el_p(5,:)); 
    max_pts = length(el_p(4,:) >= 0); 
    disp(' '); 
    fprintf(fid,['There are ',num2str(max_pts),' elements in the array.','.\n']); 
    disp(['Symmetric thinning is ',flagtxt,'.']); 
    disp(' '); 
    disp('Choose elements to be thinned by pushing left button on mouse.'); 
    disp('Terminate thinning by pushing middle or right button.'); 
    disp(' '); 
    num = 0; 
    but = 1; 
    d_col = (max(el_p(1,:))-min(el_p(1,:)))/(max_col-1); 
    if max_rows > 1 
      d_row = (max(el_p(2,:))-min(el_p(2,:)))/(max_rows-1); 
    else		        
      d_row = 0.001; 
    end  				%if max_rows  
    while (but == 1) & (num < max_pts-1) 
      [co,ro,but] = ginput(1); 
      if but == 1   
	th_pts = [co ro]*1e-03; 
	cut_elem = find((abs(el_p(2,:)-th_pts(1,2)) < d_row/2)&... 
	    (abs(el_p(1,:) - th_pts(1,1)) < d_col/2)); 
	if flagS == 1 
	  row = abs(el_p(5,cut_elem(1))); %row number 
	  col = abs(el_p(4,cut_elem(1))); %column number 
	  if (col ~= max_col - col +1) | (row ~= max_rows +1) 
	    % find the symmetric elements 
	    if max_rows > 1 
	      cut_elem = [cut_elem find((el_p(4,:) == col)... 
		      & (el_p(5,:) == (max_rows - row + 1)))... 
		      find((el_p(4,:) == (max_col - col + 1))... 
		      & (el_p(5,:) == row))... 
		      find((el_p(4,:) == (max_col - col + 1))... 
		      & (el_p(5,:) == (max_rows - row + 1)))]; 
	      num  = num + 4; 		% deleting two elements 
	    else  
	      cut_elem = [cut_elem find(el_p(4,:) == (max_col - col + 1))]; 
	      %...		      & (el_p(5,:) == (max_rows - row + 1)))]; 
	      num      = num + 2; 
	    end  
	  end  
	else		 
	  num    =  num + 1; 		% deleting one element 
	end  
	 
	cut_elem = cut_elem(find(el_p(4,cut_elem) >= 0)); 
	% setting thinned element to negative value 
	el_p(4,cut_elem)=-1*el_p(4,cut_elem); 
	viewtrsd(transducer,el_p,flagg); 
      end  				% if but == 1 
    end  				%while  
     
    if num >= max_pts - 1 
      disp('No more points can be thinned!'); 
    end  
    input('Push a key to continue.'); 
    % 
    %------------------------------------------------------------------------- 
  elseif (comm == 5) 
    %THINNING AND SENSOR DISPLACEMENT WITH RANDOM DISTRIBUTED VARIABLES 
    %------------------------------------------------------------------ 
    clc 
    old_pts = el_p; 
    set_of_elem = length(find(el_p(4,:) >= 0)); 
    disp(' '); 
    disp('Thinning by using the Matlab random generator.'); 
    fprintf(fid,['There are ',num2str(set_of_elem),' elements in the array','.\n']);     
    disp(['Symmetric thinning is ',flagtxt,'.']); 
    disp(' '); 
    disp(' Anti Gaussian distribution   : 1 '); 
    disp(' Gaussian displacement        : 2 '); 
    disp(' Gaussian distribution        : 3 '); 
    disp(' Uniform distribution         : 4 '); 
    disp(' '); 
    choice  =  input('Your choice is ?'); 
    % 
    if (choice == 4) 			%UNIFORM distribution 
      disp(' Uniform thinning'); 
      Np=input('How many elements will you delete ? '); 
      com2 = input('Give seed value :  '); 
      skip = 0; 
      if isempty(Np) | isempty(com2) 
	disp('No elements is deleted!'); 
      elseif (Np < 1) | (Np >= set_of_elem) 
	disp('Illegal number !!'); 
      else 
	if flagS == 1 
	  if (max(el_p(5,:)) == 1) & (rem(Np,2) ~= 0) 
	    disp('Symmetric thinning number of elements must be even.'); 
	    skip  = 1; 
	  elseif (max(el_p(5,:)) > 1) & (rem(Np,4) ~= 0) 
	    disp('Symmetric thinning of rectangular array, the number of '); 
	    disp('elements must be a product of four(4).'); 
	    skip  = 1; 
	  end  
	end  
	 
	if ~skip 
	  rand('seed',com2); 		% set generator seed to input value 
	  % end point limits 
	  lo = 1; 
	  upper = [max(el_p(4,:)); max(el_p(5,:))]; 
	  if upper(2) == 1 		%linear array 
	    lo       = 2; 
	    upper(1) = upper(1) - 1; 
	  end  
	  cut_el = zeros(1,Np); 
	  index = 0;  count = 0; 
	  while (index < Np) & (count < set_of_elem), % thinning loop 
	    count = count + 1; 		% number of times in loop 
	    val_draw = ceil(upper.*rand(2,1)); % draw a number 
	    % check if this element exists 
	    prune = find(el_p(4,:) == val_draw(1) & ... 
		el_p(5,:) == val_draw(2)); 
	    if flagS == 1 		%if symmetris thinning 
	      col = abs(el_p(4,prune)); %column number 
	      row = abs(el_p(5,prune)); %row number 
	      if (col ~= upper(1) - col +1) | (row ~= upper(2) +1) 
		% find the symmetric elements 
		if upper(2) > 1 	%In case of > 1 row (elevation) 
		  cut_el = [prune find((el_p(4,:) == col)... 
			  & (el_p(5,:) == (upper(2) - row + 1)))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == row))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == (upper(2) - row + 1)))]; 
		  % setting thinned element to negative value 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 4) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 4; % deleting four elements 
		  end  
		else 			%Linear case (elevation) 
		  cut_el = [prune find(el_p(4,:) == (upper(1) - col + 2))]; 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 2) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index      = index + 2; 
		  end  
		end  			%if upper(2) 
	      end  
	    else 			%else (if not flagS) 
	      cut_el   = prune; 
	      cut_el = cut_el(find(el_p(4,cut_el) >= 0)); 
	      % setting thinned element to negative value 
	      if ~isempty(cut_el) 
		el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		index    =  index + 1; 	% deleting one element 
	      end  
	    end  			%if flagS 
	  end  				%while  
	  % thinning information 
	  disp([num2str(index),' elements deleted -> Totally ',... 
		  num2str(length(find(el_p(4,:) < 0))),' elements are thinned.']); 
	  viewtrsd(transducer,el_p,flagg); 
	end  				%if ~skip 
      end  				%if isempty(Np 
   
    elseif (choice == 3)      %GAUSSIAN distribution 
      disp('Gaussian distributed thinning'); 
      Np=input('How many elements will you delete ? '); 
      com2 = input('Give seed value :  '); 
      if isempty(Np) | isempty(com2) 
	disp('No elements is deleted!'); 
      elseif (Np < 1) | (Np > set_of_elem) 
	disp('Illegal input for number of elements !!'); 
      else 				% legal number to be deleted 
	if flagS == 1 
	  if (max(el_p(5,:)) == 1) & (rem(Np,2) ~= 0) 
	    disp('Symmetric thinning number of elements must be even.'); 
	    return 
	  elseif (max(el_p(5,:)) > 1) & (rem(Np,4) ~= 0) 
	    disp('Symmetric thinning of rectangular array, the number of '); 
	    disp('elements must be a product of four(4).'); 
	    return 
	  end  
	end  
	lo  = 1; 			%lowest row number 
	upper = [max(el_p(4,:)); max(el_p(5,:))]; 
	limit = 2; 
	randn('seed',com2); 
	cut_el = zeros(1,Np); 
	index = 0;  count = 0; 
	while (index < Np) & (count < set_of_elem), 
	  count = count + 1; 
	  drawed = (2 + randn(2,1))./4; 
	  if all(drawed >= 0 & drawed <= 1), 
	    val_draw = round(lo + (upper - lo).*drawed); % legal number drawn 
	    prune = find(el_p(4,:) == val_draw(1) & ... 
		el_p(5,:) == val_draw(2)); 
	    if flagS == 1 		%if symmetris thinning 
	      col = abs(el_p(4,prune)); %column number 
	      row = abs(el_p(5,prune)); %row number 
	      if (col ~= upper(1) - col +1) | (row ~= upper(2) +1) 
		% find the symmetric element 
		if upper(2) > 1 	%In case of > 1 row (elevation) 
		  cut_el = [prune find((el_p(4,:) == col)... 
			  & (el_p(5,:) == (upper(2) - row + 1)))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == row))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == (upper(2) - row + 1)))]; 
		  % setting thinned element to negative value 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 4) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 4; % deleting four elements 
		  end  
		else 			%Linear case (elevation) 
		  cut_el = [prune find(el_p(4,:) == (upper(1) - col+1))]; 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 2) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 2; % deleting two elements 
		  end  
		end  			%if upper(2) 
	      end  
	    else 			%if ~flagS 
	      cut_el   = prune; 
	      cut_el = cut_el(find(el_p(4,cut_el) >= 0)); 
	      % setting thinned element to negative value 
	      if ~isempty(cut_el) 
		el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		index    =  index + 1; 	% deleting one element 
	      end  
	    end  			%if flagS	 
	  end  				%if all(draw 
	end  				%while 
	disp([num2str(index),' elements deleted -> Totally ',... 
	       num2str(length(find(el_p(4,:) < 0))),' elements are thinned.']); 
	viewtrsd(transducer,el_p,flagg); 
      end  				%if(isempty 
      % 
      %ANTI GAUSSIAN distribution 
      %-------------------------- 
    elseif (choice == 1)  
      disp('Anti-Gaussian thinning'); 
      Np = input('How many elements will you delete ? '); 
      com = input('Give seed value :  ','s'); 
      if isempty(Np) | isempty(com) 
	disp('No elements are deleted!'); 
      elseif (Np < 1) | (Np > set_of_elem) 
	disp('Illegal input for number of elements !!'); 
      else 				% legal number to be deleted 
	if flagS == 1 
	  if (max(el_p(5,:)) == 1) & (rem(Np,2) ~= 0) 
	    disp('Symmetric thinning number of elements must be even.'); 
	    return 
	  elseif (max(el_p(5,:)) > 1) & (rem(Np,4) ~= 0) 
	    disp('Symmetric thinning of rectangular array, the number of '); 
	    disp('elements must be a product of four(4).'); 
	    return 
	  end  
	end  
	lo  = 1; 
	upper = [max(el_p(4,:)); max(el_p(5,:))]; 
	limit  = 2.5; 
	randn('seed',str2num(com)); 
	cut_el = zeros(1,Np); 
	index  = 0;  count = 0; 
	 
	while (index < Np) & (count < 2*set_of_elem), 
	  count = count + 1; 
	  drawed = randn(2,1); 
	  %  
	  % drawed value in [-1,0] and in [0,1] => legal value 
	  % Left distribution 
	  if all(drawed >= 0 & drawed <= limit), 
	    drawed1 = drawed./limit; 
	    value1 = round(lo + (upper - lo).*drawed1); 
	    prune1 = find(el_p(4,:) == value1(1) & ... 
		el_p(5,:) == value1(2)); 
	    if flagS == 1 		%if symmetris thinning 
	      col = abs(el_p(4,prune1)); %column number 
	      row = abs(el_p(5,prune1)); %row number 
	      if (col ~= upper(1) - col +1) | (row ~= upper(2) +1) 
		% find the symmetric element 
		if upper(2) > 1 	%In case of > 1 row (elevation) 
		  cut_el = [prune1 find((el_p(4,:) == col)... 
			  & (el_p(5,:) == (upper(2) - row + 1)))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == row))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == (upper(2) - row + 1)))]; 
		  % setting thinned element to negative value 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 4) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 4; % deleting four elements 
		  end  
		else 			%Linear case (elevation) 
		  cut_el = [prune1 find(el_p(4,:) == (upper(1) - col + 1))]; 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 2) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 2; % deleting two elements 
		  end  
		end  			%if upper(2) 
	      end  
	    else 			%if ~flagS 
	      cut_el   = prune1; 
	      cut_el = cut_el(find(el_p(4,cut_el) >= 0)); 
	      % setting thinned element to negative value 
	      if ~isempty(cut_el) & (cut_el ~= 0) 
		el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		index    =  index + 1; 	% deleting one element 
	      end  
	    end  			%if flagS	 
	  end  				%if all(val 
	  % 
	  %Right distribution 
	  if all(drawed >= -limit & drawed <= 0), 
	    drawed2 = drawed./limit; 
	    value2 = round(upper + (upper - lo).*drawed2); 
	    prune2 = find(el_p(4,:) == value2(1) & ... 
		el_p(5,:) == value2(2)); 
	    if flagS == 1 		%if symmetris thinning 
	      col = abs(el_p(4,prune2)); %column number 
	      row = abs(el_p(5,prune2)); %row number 
	      if (col ~= upper(1) - col +1) | (row ~= upper(2) +1) 
		% find the symmetric element 
		if upper(2) > 1 	%In case of > 1 row (elevation) 
		  cut_el = [prune2 find((el_p(4,:) == col)... 
			  & (el_p(5,:) == (upper(2) - row + 1)))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == row))... 
			  find((el_p(4,:) == (upper(1) - col + 1))... 
			  & (el_p(5,:) == (upper(2) - row + 1)))]; 
		  % setting thinned element to negative value 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 4) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 4; % deleting four elements 
		  end  
		else 			%Linear case (elevation) 
		  cut_el = [prune2 find(el_p(4,:) == (upper(1) - col + 1))]; 
		  if ~isempty(cut_el) & (max(size(cut_el)) == 2) 
		    el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		    index  = index + 2; % deleting two elements 
		  end  
		end  			%if upper(2) 
	      end  
	    else 			%if ~flagS 
	      cut_el   = prune2; 
	      cut_el = cut_el(find(el_p(4,cut_el) >= 0)); 
	      % setting thinned element to negative value 
	      if ~isempty(cut_el) & (cut_el ~= 0) 
		el_p(4,cut_el) =  -1*el_p(4,cut_el); 
		index    =  index + 1; 	% deleting one element 
	      end  
	    end  			%if flagS	 
	  end  				%if all(val 
	end  				%while 
      disp(['Totally ',num2str(length(find(el_p(4,:) < 0))),... 
	      ' elements are thinned from this array.']); 
      viewtrsd(transducer,el_p,flagg); 
      end  				%if(isempty 
 
    elseif (choice == 2) 		%GAUSSIAN DISPLACEMENT 
      disp('Gaussian distributed displacement of sensor locations'); 
      if (max(size(el_p)) ~= max(size(el_p(1,el_p(4,:) >= 0 )))) 
	disp(' This routine demands a filled array!'); 
	disp(' Return!'); 
	break 
      end  
      disp('Is the array equally spaced? [y/n]'); 
      [b1,b2,butt1]=ginput(1); 
      if butt1 == 110 
	disp('Configurate new transducer!'); 
	break 
      else 
	N       = transducer(2); 
	eqspace = transducer(1)/N; 
	viewtrsd(transducer,el_p,flagg); 
	odevn   = rem(N,2); 		%odevn=0 -> even and odevn=1 -> odd 
	ep      = el_p(1,el_p(1,:) > 0 ); 
	Npos    = max(size(ep)); 
	dislim  = eqspace/2; 
	sigma   = 0.9; 
	for k=1:Npos 
	  draw      = sigma*eqspace*randn(1); 
	  % check if within limits 
	  while (draw > dislim) | (draw < -dislim) 
	    draw    = sigma*eqspace*randn(1); 
	  end  
	  if k < Npos 
	    adjusted(k) = ep(k) + draw; 
	  else 
	    adjusted(k) = ep(k); 	%not displace end  element 
	  end  				%if k 
	end  				%for k=1 
     
	if odevn 
	  ep   = [-fliplr(adjusted) 0 adjusted]; 
	else 
	  ep   = [-fliplr(adjusted) adjusted]; 
	end  
	subplot(2,1,1) 
	plot(1e3*el_p(1,:),zeros(max(size(el_p(1,:)))),'mo'); 
	hold on 
	plot(1e3*ep,zeros(max(size(ep))),'c*');grid 
	hold off 
	el_p(1,:) = ep; 
      end  				%if butt1 
    elseif  ~any(choice == [1 2 3 4]) 
      disp('Your choice is unfamiliar to this computer.'); 
    end  				% END  of RANDOM PART 
    input('Push a key to continue.'); 
    %---------------------------------------------------------------------- 
  elseif (comm == 6) 			%THINNING OF CIRCULAR TRANSDUCER 
    %------------------------------ 
    old_pts = el_p; 
    if (flagg ~= 3) | (transducer(18) ~= 2), 
      disp('Error!! Input is not a circular transducer! '); 
    else 
      disp(['Points are deleted by specifying a number or a vector ']); 
      disp(['in the interval from 1 to ',num2str(max(elem_pts(4,:)))]); 
      choice = input('Choose point(s) to be thinned : ','s'); 
      if isempty(comm) 
	disp('No elements deleted!!'); 
	 
      else 
	cut_p = str2num(choice) 
	for k=1:length(cut_p), 
	  prune = find(el_p(4,:) == cut_p(k)); 
	  el_p(:,prune) = []; 
	end  				%for loop 
      end  				%if ~isempty 
      viewtrsd(transducer,el_p,flagg); 
    end  				%if flagg == 3 
    input('Push a key to continue.'); 
  %---------------------------------------------------------------------- 
  elseif (comm == 7) 			%INSERT ARRAY ELEMENTS 
    %----------------------- 
    old_pts = el_p; 
    disp(' '); 
    fprintf(fid,['There are ',num2str(max(size(el_p(1,el_p(4,:) < 0)))),... 
	    ' thinned elements','.\n']); 
    disp(['Symmetric thinning is ',flagtxt,'.']); 
    disp(' '); 
    disp('Insert deleted elements by pushing left button on mouse.'); 
    disp('Terminate thinning by pushing middle or right button. '); 
    disp('with the mouse button. The program chooses the nearest element.'); 
    fprintf(fid,['There are ',num2str(max(size(el_p(1,el_p(4,:) < 0)))),... 
	    ' thinned elements','.\n']); 
    disp(' '); 
    disp('>>> '); 
    max_col    = max(abs(el_p(4,:))); 
    max_row    = max(abs(el_p(5,:))); 
    max_th_pts = max(size(el_p(4,el_p(4,:) < 0))); 
    num    =  0; 
    but    =  1; 
    d_col = (max(el_p(1,:))-min(el_p(1,:)))/(max_col-1); 
	 
    if max_row > 1 
      d_row = (max(el_p(2,:))-min(el_p(2,:)))/(max_row-1); 
    else		        
      d_row = 0.001; 
    end  				%if max_rows  
     
    while (but == 1) & (num < max_th_pts - 1) 
      [cx,rx,but]  = ginput(1); 
      if but == 1 
	col  =  cx*1e-03; 
	row  =  rx*1e-03; 
	cut_elem = find((abs(el_p(1,:) - col) < d_col/2)&... 
	    (abs(el_p(2,:) - row) < d_row/2)); 
 
        if flagS == 1 
	  row = abs(el_p(5,cut_elem(1))); %row number 
	  col = abs(el_p(4,cut_elem(1))); %column number 
	  if (col ~= max_col - col +1) | (row ~= max_row +1) 
	    % find the symmetric elements 
	    cut_elem = [cut_elem find((abs(el_p(4,:)) == (max_col -col + 1))... 
		    & (abs(el_p(5,:)) == (max_row - row + 1)))]; 
	    num  = num + 2; 		% deleting two elements 
	  end  
	else		 
	  num    =  num + 1; 		% deleting one element 
	end  
   
	cut_elem = cut_elem(find(el_p(4,cut_elem) < 0)); 
	% setting inserted elements to positive value 
	el_p(4,cut_elem)=-1*el_p(4,cut_elem); 
	viewtrsd(transducer,el_p,flagg); 
      end  				% if but == 1 
     end  				% while  
 
     if num >= max_th_pts - 1 
       disp(' Array is filled.'); 
     end  
    input('Push a key to continue.'); 
    % 
    %----------------------------------------------------------------------- 
  elseif (comm == 8) 			%ELEMENT PLACEMENT AT NEW LOCATIONS 
    %------------- 
    fprintf(fid,[num2str(N),' elements will be placed with locations','\n']); 
    disp('determined by a geometric series. The cardinal number will be '); 
    disp('raised to the power from 1 to N (i.e. the number of sensors)'); 
    aper      = max(elem_pts(1,:))-min(elem_pts(1,:)); 
    a_value   = input('Give in a value for the cardinal number : '); 
    locations = geospace(a_value,N,aper); 
    if ~isempty(locations) 
      el_p(1,:)  = locations; 		% set local elements to new locations 
      el_p(4,:)  = abs(el_p(4,:)); 	%restoring eventually thinned elements 
      elem_pts(1,:) = locations; 	% set system elements to new locations 
      viewtrsd(transducer,el_p,flagg); 
    else 
      disp('No elements inserted.'); 
    end  
    input('Push a key to continue.'); 
    % 
    %----------------------------------------------------------------------- 
  elseif (comm == 9) 			%RESTORE ARRAY 
    %------------- 
    restore = find(el_p(4,:) <= 0); 
    el_p(4,restore) = -1*el_p(4,restore); 
    disp('The array is restored!'); 
    viewtrsd(transducer,el_p,flagg); 
    input('Push a key to continue.'); 
    % 
    %----------------------------------------------------------------------- 
  elseif (comm == 10) 			%UNDO LAST CHANGE 
    %---------------- 
    el_p = old_pts; 
    disp(['Last change of array configuration is undone.!']); 
    viewtrsd(transducer,el_p,flagg); 
    input('Push a key to continue.'); 
    % 
    %----------------------------------------------------------------------- 
  elseif (comm == 0) 			%CHANGE STATUS ON SYMMETRY FLAG 
    %------------------------------ 
    if flagS == 0 
      flagS = 1; 
      flagtxt = 'ON '; 
    else 
      flagS = 0; 
      flagtxt = 'OFF'; 
    end  
    % 
    % 
  elseif (comm < 0) 
    done = 1; 
  else disp('Unknown command ! (Negative number to quit.)'); 
  end  					%if ~isempty(comm 
end  					%while ~done 
 
No_of_elem = length(el_p(4,:)) - length(find(el_p(4,:) <= 0)); 
fprintf('There are %4.0f elements in the array. \n',No_of_elem); 
fprintf('\n\nFinished!\n');
% ------------------------------------------------------------------------- 
   

