%------------------------------------------------------------------------
% Routine     : busimtxt
%
% Description : Configuring excitation-parameters - beamforming
%                   txt-file
%
% Language    : MATLAB 4.1
% Written by  : Vebjorn Berre 4/5-93
% Version no. : 3.0
% Version no. : 3.1 FT 02.09.93 Corrected text for apodizing
%	      : 3.2 FT 19.01.94 Added ; after fprintf-statements
%	      : 3.3 FT 08.02.94 Added text for focusing algorithm parameters
%	                        & dynamic focusing.
%               3.4 FT 20.03.94 Phase noise removed -> comments
%               3.5 FT 20.04.94 Phase noise included
%               3.6 SH 30.11.94 Corrected spelling errors in output
%               3.7 SH  4. 1.95 Added output of f-number
%               3.8 SH 27.02.95 Corrected f-number for annular array,spherical coordinates
%               3.9 LO 31.03.95 Added semicolon behind f-number 
%               4.0 SH 12.04.95 Added flagg(4)=4 and
%                               excitation(2:4) now in polar coordinates
%               4.1 SH 15.09.95 Small fix for annular array and rect. coord.
%               4.2 NA 23.10.96 Provisions for sub aperture imaging
%               4.3 SH 25.03.97 excitation(24) for focus type (sph, conical)
%		4.4 NA 16.04.97 Hybrid focusing
%
% Called by   : busim, bdynusim
% Calling     : deltxt
%------------------------------------------------------------------------

  fprintf(fid,'\t\t--------     BEAMFORMING SUBMENU     -----\n');
  fprintf(fid,'\n');

%
% choice of focusing type SH 17.01.97
%
if length(excitation) >= 24
  if (excitation(24) == 1)
    fprintf(fid,'24) Focusing type\t\t\t: Conical\n'); 
  elseif (excitation(24) == 2)
    fprintf(fid,'24) Focusing type\t\t\t: Hybrid [average(spherical,axicon)]\n'); 
  else
    fprintf(fid,'24) Focusing type\t\t\t: Spherical\n');
  end    
else  
  fprintf(fid,'24) Focusing type\t\t\t: Spherical\n');
end


%
% parameters for fixed focus
%

  if flagg(1)==1

    fprintf(fid,'\n                 Fixed focusing - transmit mode\n');
    fprintf(fid,' \n');
    if (length(excitation) <= 24) excitation(24:25) = [0 0]; end
    if (excitation(24) == 0)
      if flagg(2)==1 			% rectangular array, etc
	tekst=fixtxt(fast(1),excitation(2));
	fprintf(fid,['2) Electronic focusing	-  ', tekst,'\n']);
	tekst=fixtxt(fast(2),excitation(3));
	fprintf(fid,['3) Electronic focusing	-  ', tekst,'\n']);
	tekst=fixtxt(fast(3),excitation(4));
	fprintf(fid,['4) Electronic focusing	-  ', tekst,'\n']);
      elseif flagg(2)==3 & flagg(4)==3 | flagg(4) == 4 % annular array + spherical
	fprintf(fid,'2) Electronic focusing depth  [mm] \t : %6.0f \n',...
	    excitation(2)*1e3);
      elseif flagg(2)==3 & flagg(4)==1 	% annular array + rectangular
	fprintf(fid,'4) Electronic focusing depth  [mm] \t : %6.0f \n',...
	    sqrt(sum(excitation(2:4).^2))*1e3);	       
      end
%
   % f/stop
   %

    if flagg(4) == 1	% rectangular coordinates
        FN = sqrt(sum(excitation(2:4).^2))/transducer(1);
    else              
        FN = excitation(2)/transducer(1);
    end
    fprintf(fid,'29) f-number \t\t\t\t: %6.2f \n',FN);
    elseif excitation(24) == 1,
%
% conical focusing
%
	tekst=fixtxt(fast(2),excitation(3));
	fprintf(fid,['3) Electronic focusing	-  ', tekst,'\n']);
	tekst=fixtxt(fast(3),excitation(4));
	fprintf(fid,['4) Electronic focusing	-  ', tekst,'\n']);
	fprintf(fid,'25) Axicon angle 	-  \t\t: %6.2f [deg]\n', ...
	    excitation(25)*180/pi);

      if (excitation(25) ~= 0)
	tgfi = tan(excitation(25));
%
% modified to simpler expression 25.3.97:
% was (tgfi+1/tgfi)
%
%        if (flagg(2) == 1), % rectangular array
%	  dof = 500*transducer(1)*cos(excitation(4))/tgfi; % e(4) is depth internally!
%        else
	   dof = 500*transducer(1)/tgfi;
%	end   
      else
	dof = Inf;
      end
	fprintf(fid,'    Estimated depth of field \t\t: %6.2f [mm]\n',dof);
    else

%
% hybrid focusing
%
      if flagg(2)==1 			% rectangular array, etc
	tekst=fixtxt(fast(1),excitation(2));
	fprintf(fid,['2) Electronic focusing	-  ', tekst,'\n']);
	tekst=fixtxt(fast(2),excitation(3));
	fprintf(fid,['3) Electronic focusing	-  ', tekst,'\n']);
	tekst=fixtxt(fast(3),excitation(4));
	fprintf(fid,['4) Electronic focusing	-  ', tekst,'\n']);
      elseif flagg(2)==3 & flagg(4)==3 | flagg(4) == 4 % annular array + spherical
	fprintf(fid,'2) Electronic focusing depth  [mm] \t : %6.0f \n',...
	    excitation(2)*1e3);
      elseif flagg(2)==3 & flagg(4)==1 	% annular array + rectangular
	fprintf(fid,'4) Electronic focusing depth  [mm] \t : %6.0f \n',...
	    sqrt(sum(excitation(2:4).^2))*1e3);	       
      end

	fprintf(fid,'25) Axicon angle 	-  \t\t: %6.2f [deg]\n', ...
	    excitation(25)*180/pi);

      if (excitation(25) ~= 0)
	tgfi = tan(excitation(25));
	dof = 500*transducer(1)/tgfi;
      else
	dof = Inf;
      end
      fprintf(fid,'    Estimated depth of field \t\t: %6.2f [mm]\n',dof);
    end



%
% parameters for dynamic focus
%

  elseif flagg(1)==2

    if excitation(17)==0
      tekst = 'Transmit';
    elseif excitation(17)==1
      tekst = 'Receive';
    else
      tekst = '2-way';
    end
    fprintf(fid,['                 Dynamic focusing - ',tekst,' mode\n']);
    fprintf(fid,' \n');
    if excitation(18)~=2
      if excitation(17)
	if excitation(17)==2
	  fprintf(fid,' Receive :\n');
	end;
	fprintf(fid,'19) Number of focal zones \t\t : %6.0f \n',...
	    excitation(19));
	fprintf(fid,'20) Start depth of first focal zone [mm] : %6.0f \n',...
	   excitation(20)*1e3);
        fprintf(fid,'21) End depth of last focal zone    [mm] : %6.0f \n\n',...
	   excitation(21)*1e3);
      end
      if excitation(17)~=1
	if excitation(17)==2
	  fprintf(fid,' Transmit :\n');
	end;
	fprintf(fid,'2) Number of focal zones \t\t : %6.0f \n',...
	    excitation(2));
      fprintf(fid,'3) Start depth of first focal zone  [mm] : %6.0f \n',...
	  excitation(3)*1e3);
      fprintf(fid,'4) End depth of last focal zone     [mm] : %6.0f \n\n',...
	  excitation(4)*1e3);
      end
    end;


%
% parameters for microsteering of focus
%

  elseif flagg(1)==3,
     fprintf(fid,'22) Micro steered direction [deg]\t: %4.2f \n',excitation(22)*180/pi);
     fprintf(fid,'23) # of sub apertures\t\t\t: %4.0f \n',excitation(23));
     if flagg(2)==1 % rectangular array, etc
       tekst=fixtxt(fast(1),excitation(2));
       fprintf(fid,['2) Electronic focusing	-  ', tekst,'\n']);
       tekst=fixtxt(fast(2),excitation(3));
       fprintf(fid,['3) Electronic focusing	-  ', tekst,'\n']);
       tekst=fixtxt(fast(3),excitation(4));
       fprintf(fid,['4) Electronic focusing	-  ', tekst,'\n']);

     end
  end

 
  if flagg(2) == 1,
  	[az,el] = apodtxt( excitation(5), excitation(6) );
  	fprintf(fid,['5) Apodization\t\t   ', az,'\n']);
  	fprintf(fid,['6) Apodization\t\t   ', el,'\n']);
  else
	[an] = apodtxt(excitation(5));
  	fprintf(fid,['5) Apodization\t\t\t         : ', an,'\n']);
  end
  fprintf(fid,['7) Phase Noise \t\t\t\t :', num2str(phasetxt(excitation(7))),'\n']);
  if excitation(7)==1
    fprintf(fid,'8) Standard deviation \t: %6.2f lambda = %6.2f ns \n',...
	excitation(8),excitation(8)/excitation(1)*1e9);
  elseif excitation(7)==2
    fprintf(fid,'8) Random seed start number \t\t : %4.0f \n',excitation(8));
  elseif excitation(7)==3
    fprintf(fid,['8) Get a description of vector containing '...
	    'User-Defined Phase Noise \n']);
  end
  fprintf(fid,' \n');
  fprintf(fid,'  Parameters used in focusing algorithm : \n\n');
  fprintf(fid,'14) Speed of Sound \t\t c [m/s] = %6.0f \n',excitation(14));
  if flagg(2)==3 & flagg(3)==2 & (flagg(1)~=2 | excitation(18)~=2)
    if excitation(15)==0 
      fprintf(fid,['15) Transducer diameter \t D  \t : Real Transducer',...
	  ' Diameter is used \n']);
    else
      fprintf(fid,'15) Transducer diameter \t D   [mm]    = %6.2f \n',...
          excitation(15)*1e3);
    end
    if excitation(16)==0 
      fprintf(fid,['16) Radius of Curvature \t ROC \t : Real Transducer',...
	  ' ROC is used \n']);
    else
      fprintf(fid,'16) Radius of Curvature \t ROC [mm]    = %6.2f \n',...
          excitation(16)*1e3);
    end
  end
  if flagg(1)==2 & flagg(3)==2
    fprintf(fid,['17) Focus mode   \t\t\t : ',tekst,' \n']);
    if excitation(18)==0
      tekst = 'Focusing Algorithm';
    elseif excitation(18)==1
      tekst = 'Focusing Algorithm + const';
    else
      tekst = 'Manual';
    end
    fprintf(fid,['18) Calculation of Electronic Delays   \t : ',tekst,' \n']);
    if excitation(18)
      if excitation(17)==0 | excitation(17)==2
	deltxt(fid,elecdelt,'transmit',transducer,2-excitation(18))
      end
      if excitation(17)==1 | excitation(17)==2
	deltxt(fid,elecdelr,'receive ',transducer,2-excitation(18))
      end	
    end
  end
  fprintf(fid,' \n');
