%------------------------------------------------------------------------
% Routine     : eusim
%
% Description : Configuring excitation-parameters (PW)
%		If a user-defined pulse is chosen (excitation(13)=1),
%		the pulse must be defined in a global variable, pvector,
%		with uniform sample time between each element, and the
%		sample time given by the first element of pvector.
%		If individual user-defined pulses on each element are
%		to be used, the pulses must be defined by global vari-
%		ables, pvector1, pvector2, ... pvectorN, where N is the
%		number of elements on the transducer. pvector1, pvector2
%		etc. must be on the same format as pvector described above.
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre
%
% Version no. : 1.0 VEB 15.02.93
% Version no. : 1.5 VEB 17.02.93
% Version no. : 2.0 SH  06.04.93
% Version no. : 2.5 VEB 30.04.93
% Version no. : 3.0 FT  23.08.93
% Version no. : 3.1 FT  06.01.93 Added comments/individual pulses
% Version no. : 3.2 FT  07.01.93 added transducer in function-call
%             : 3.5 FT  08.02.94 Changed Interp.fact. to quantizing on/off
%             : 3.6 FT  23.02.94 Removed disp('EXIT = "x"')
%             : 3.7 SH  16.03.95 Spelling error of weighting
%             : 3.8 EH  22.03.95 Added warning  about interpolation of
%                                userdefined pulses, and modified recommendation
%                                on choice of frequency.
%                                Allow only positive integer number of 
%                                oscillations in Ultrasim pulse
%               3.9 SH  10.04.95 Allowed infinite pulse length
%               4.0 SH  18.03.99 Turns of pulse weight for CW
%                                always assigned value to pvec, plength
%
%
% Called by   : usimcnf
% Calling     : eusimtxt, makepuls
%------------------------------------------------------------------------

function [excitation,pvec,plength]=eusim(excitation,flagg,transducer)


tmp=size(excitation);
if tmp(2)<13
	tmp=excitation;
	excitation=zeros([1,13]);
	excitation([1:1:length(tmp)])=tmp;
end

fid=1;
com1=0;
while com1~='x'
  clc

  eusimtxt;
  
  disp('	CHANGE 	= "number"')
  com1 = input('-> Decision (<CR> = exit): ','s');
  if isempty(com1) com1 = 'x'; end
  if length(com1)==1 com1=['0',com1];end
  if length(com1)>2
    com1 = '00'
  end
  

  % changing of parameters

  if com1=='01' 
    temp=input('Frequency (MHz)	=  ');
    if ~isempty(temp) excitation(1)=temp*1e6; end
  elseif com1=='09'
    temp=input('transmitted pulse length (# oscillations) = ');
    if ~isempty(temp) 
       if (temp-fix(temp)) == 0 & temp > 0 | isinf(temp)
  	  excitation(9)=temp;
       else
          disp(' Pulse length must be a natural number or infinity!')
          pause(2)
       end 
    end
    if isinf(excitation(9)),
      excitation(10) = 0; 		% turn off pulse weighting for CW
    end
  elseif com1=='10'
    temp=input('pulse weighting (none = 0, cosine = 1) : ');
    if ~isempty(temp) & find(temp==[0 1])
      excitation(10)=temp; 
    end
  elseif com1=='12'
    temp=menu35_0('Quantizing of Time Delays : ','Off','On');
    if ~isempty(temp) & find(temp==[0 1])
       excitation(12)=temp; 
    end
  elseif com1=='11' 
    temp=input('Sampling frequency (Fs) [MHz]	=  ');
    if ~isempty(temp) excitation(11)=temp*1e6; end
  elseif com1=='13' 
     if flagg(3)~=2
       temp = menu35_0('Choose PulseType',...
	   'Ultrasim (As defined in the above menu)','User Defined',...
	   'User Defined - Individual pulses for each element',...
	   'User Defined - Individual pulses for each element - CrossTalk (not yet implemented)');
       if ~isempty(temp) & find(temp==[0 1 2])
	 excitation(13)=temp; 
       end
    else
       temp = menu35_0('Choose PulseType',...
	   'Ultrasim (As defined in the above menu)','User Defined');
       if ~isempty(temp) & find(temp==[0 1])
	 excitation(13)=temp; 
       end
    end
    if temp==1
	disp(' Experimental Pulse must be defined by a vector "pvector", where')
	disp(' the first element is the sampling interval between the other');
	disp(' elements. Note that the chosen frequency in the above menu')
	disp(' should be at least as large as the frequency of the Experimental')
	disp(' Pulse.')
	disp(' "pvector" must be declared as a global variable. If you are')
	disp(' unfamiliar with the use of global variables, you are strongly recommended')
	disp(' to read the document "globalvar.tex" which is found in the ultrasim')
	disp(' documentation directory');
        disp(' Be aware that interpolation is done on "pvector", so be ')
        disp(' careful about pulses wich are not smooth.');
	dummy = input('Press <Enter> to Continue ...');
    elseif temp==2 & flagg(3)~=2 
    	if flagg(2)==1 & transducer(6)>1
	   disp(' Not yet implemented for 1.5D Arrays - Try again later...');
	   excitation(13) = 0;
	else 

	disp(' Experimental Pulses must be defined by vectors "pvector1", "pvector2",');
	disp(' ...,"pvectorN", where N is the total number of elements. The first')
	disp(' element of each vector must be the sampling interval between the other');
	disp(' elements. Note that the chosen frequency in the above menu should be')
	disp(' at least as large  as the frequency of the Experimental Pulses.')
	disp(' "pvector1","pvector2",etc  must be declared as global variables. If you are')
	disp(' unfamiliar with the use of global variables, you are strongly recommended')
	disp(' to read the document "globalvar.tex" which is found in the ultrasim')
	disp(' documentation directory');
        disp(' Be aware that interpolation is done on "pvectorN", so be ')
        disp(' careful about pulses wich are not smooth.');
	end

	dummy = input('Press <Enter> to Continue ...');
    end
  end
end
if excitation(13)==0
  pvec = [];
  plength = [];
end

if excitation(13)==1
    global pvector
    if exist('pvector') == 1,
	[pvec,plength]=makepuls(excitation,pvector);
    else
	disp('WARNING!!! The system cannot find variable pvector');
	disp('           User Defined Pulse must be defined in pvector');
	excitation(13) = 0;
    end
end
if excitation(13)==2 | excitation(13)==3
    for n = 1:transducer(2)
	eval(['clear pvector',num2str(n)])
	eval(['global pvector',num2str(n)])
	eval(['plot(pvector',num2str(n),')'])
 	eval(['title(''pvector',num2str(n),''')'])
	dummy = input('Press <Enter> to Continue ...');
   	if eval(['exist(''pvector',num2str(n),''') == 1']),
	   [pvec(n,:),plength(n)]=makepuls(excitation,eval(['pvector',num2str(n)]));
    	else
	   disp(['WARNING!!! The system cannot find variable pvector',num2str(n)]);
	   disp('        ABORTED!!!');
	   excitation(13) = 0;
	   return
    	end
    end
end








