%
% [x,y] = hein(a,b,p)
% Written by      : Sverre Holm
% Version no.     : 1.0
% Date            : 12. Nov 1992  
% Called by       : rectangular.m
% Modified        : 2.4.93 SH
%                 : 29.04.96 KE Added for octagonal transducer. p = -8
% Routines called : none
% Load files      : none
%
% Purpose:	  plotting general formula for rounded rectangle
%------------------------------------------------------------------------
%
%	a = Long-axis
%	b = Short-axis
%	p = exponent (2-ellipse, 2.5-Piet Hein, -> rectangle
%       N = no of points to compute shape function for
%       plotpar = 0 no plot, else plot
%	
	function [x,y] = hein(a,b,p,N,plotpar)
	x1 = -0:a*2/N:a;
	x2 = -a:a*2/N:-a*2/N;

	if p > 0,
%
% use generalized circle
%
		y1 = max(b^p -(b*x1/a).^p,0 ).^(1/p);
		y2 = max(b^p -(b*(-x2)/a).^p,0 ).^(1/p);

% --------------------------------
% Added fir Octagonal transducer
% Added 29/04-96
        elseif p == -8
		y1=ones(size(x1))*b;
		y2=ones(size(x2))*b;
		hexag=find(x1>a/3);
		y1(hexag)=b*(4/3 - x1(hexag)/a);
		hexag=find(x2<-a/3);
		y2(hexag)=b*(4/3 + x2(hexag)/a);

%
% else use rectangle
%

	else
		y1 =  ones(size(x1))*b/2;
		y2 =  ones(size(x2))*b/2;
	end
	x = [x2 x1];
	y = [y2 y1];

	if plotpar ~= 0,

	if (a==b),
		axis('square')
		disp('square')
	else
		axis('normal')
	end
	plot(1000*x,1000*y,'r-',1000*x,-y*1000,'r-')
	title(['Generalized ellipse, exponent ',num2str(p)])
	xlabel(['Long-axis: ',num2str(a*1000)])
	ylabel(['Short-axis: ',num2str(b*1000)])
	grid

	end
