% Written by      : Sverre Holm
% Version no.     : 1.0
% Date            : 19.3.93           
% Revisions       : 1.1 31.05.96 SH Octagonal shape, moved from KE's code in rectangu.m
%
% Called by       : rectangu.m
% Routines called : none
% Load files      : none
%
% Purpose:	    check if a coordinate value is inside or outside element
%                   p > 0 shape of element is given by piet hein function.
%                   p = -8 octagonal shape
%                   all other values: rectangular shape
%------------------------------------------------------------------------
%
function [y,in]=in_out(x,a,b,p)
%
% y: output y-coordinate
% in: flag = 1 if in array, 0 if outside
% a: half-aperture in azimuth
% b: half-aperture in elevation
% x: input x-coordinate
% p: exponent 
%
	if (abs(x) > a),
		y = 0;
		in = 0;
	else 
		in = 1;		

		if (p > 0), 	% generalized ellipse 

			y = (b^p -(b*abs(x)/a)^p ) ^ (1/p);

		elseif (p == -8) 	% octagonal

	       		if abs(x)<= a/3
	          		y = b;
     	       		else
	          		y = (4/3 - abs(x)/a)*b;
	       		end

		else 		% rectangular
			y = b;
		end
	end
 
