%------------------------------------------------------------------------
% Routine     : musimtxt
%
% Description : Configuring medium-parameters - txt-file
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no. : 3.0 VEB 12.05.93
% Version no. : 3.1 SH  07.09.93
% Version no. : 3.2 FT  27.09.93 Added text for 3D Layered medium
% Version no. : 3.3 FT  07.01.94 Converting some parameters to mm
%             : 3.4 FT  19.01.94 Added ; after fprintf-statements
%             : 3.5 FT  02.02.94 Added function class 5
%             : 3.6 FT  20.03.94 Not displaying 1. layer func.parameters
%               3.7 FT  28.09.94 Added text for attenuation (3D)
%               3.8 EH  27.11.95 Added third function type for layered 3D
%               3.9 EH  19.02.96 Added fourth 3D function type (class no. 7)
%               4.0 LO  02.10.96 Added extra text about absorption in menu
%               4.1 SH  07.05.98 Slight coorection of absorption text
% Called by   : musim
% Calling     : mediatxt, modeltxt
%------------------------------------------------------------------------

  clear tmpmedia;
  fprintf(fid,'\t\t--------     MEDIUM SUBMENU     -----\n');
  fprintf(fid,['Model  : ',num2str(modeltxt(flagg(3))),'\n']);
  fprintf(fid,'\n');

  if flagg(3)==1
    fprintf(fid,'1) Speed of Sound \t\t c \t= %6.0f \n',media(1,2));
    fprintf(fid,'2) Impedance \t\t\t Z \t= %6.0f MRayl\n',media(1,8)*1e-6);
    fprintf(fid,'3) Absorption - alpha \t\t alpha \t= %6.3f Np/m\n',media(1,9));
    fprintf(fid,'4) Absorption - beta \t\t beta \t= %6.3f exp(-alpha*f^beta)\n',media(1,10));
    if media(1,10)==1
      tmp=['   3) and 4) => \t\t Absorp.= %6.3f dB/MHz/cm \n'];
      fprintf(fid,tmp,media(1,9)/(10*log(10)));
    end
  elseif flagg(3)==2 | flagg(3)==3
    tmpmedia(:,[1])=[1:length(media(:,1))]';
    tmpmedia(:,[2])=media(:,[1])*1e3;
    tmpmedia(:,[6])=media(:,[9])*1e-6;
    tmpmedia(:,[3 4 5 7 8 9 10 11 12])=media(:,[2 10 11 3 4 5 6 7 8]);
    if flagg(3)==2
	fprintf(fid,'LAYER  z     c    alpha  beta   Z   func   a     b      c      d\n');
	 fprintf(fid,'      [mm] [m/s] 1/(m*MHz) -  MRayl \n ');
	fprintf(fid,'\n');
	tmpmedia(:,[1])=[1:length(media(:,1))]';
	tmpmedia(:,[2])=media(:,[1])*1e3;
	tmpmedia(:,[6])=media(:,[9])*1e-6;
	tmpmedia(:,[3 4 5 7 8 9 10 11 12])=media(:,[2 10 11 3 4 5 6 7 8]);
	ind = find(tmpmedia(:,7)==1);
	if ~isempty(ind)
	   for n = 1:3
	      tmpmedia(ind,8+n) = tmpmedia(ind,8+n)/10^(3*n);
	   end
	end
	ind = find(tmpmedia(:,7)==2);
	if ~isempty(ind)
	   tmpmedia(ind,[8 9 11]) = tmpmedia(ind,[8 9 11])*1e3;
	end
	tmpmedia(1,8:11) = tmpmedia(1,8:11)*1e3;
	tmpmedia(1,10) = tmpmedia(1,10)*180/pi*1e-3;
	ind = find(tmpmedia(:,7)==4);
	if ~isempty(ind)
	   tmpmedia(ind,[8 9 10]) = tmpmedia(ind,[8 9 10])*1e3;
	end
	fprintf(fid,'#%2.0f %6.2f %5.0f %6.3f %4.1f %6.3f %2.0f %6.3f %6.3f %6.3f %6.3f \n',tmpmedia(:,1:11)');
	fprintf(fid,' \n');
	fprintf(fid,['func=1 : ',num2str(mediatxt(flagg,1)),'\n']);
	fprintf(fid,['func=2 : ',num2str(mediatxt(flagg,2)),'\n']);
	fprintf(fid,['func=3 : ',num2str(mediatxt(flagg,3)),'\n']);
	fprintf(fid,['func=4 : ',num2str(mediatxt(flagg,4)),'\n']);
	fprintf(fid,['func=5 : ',num2str(mediatxt(flagg,5)),'\n']);
   elseif flagg(3)==3
	fprintf(fid,'LAYER  z     c    alpha  beta   Z   func   a     b      c      d      e\n');
	 fprintf(fid,'      [mm] [m/s] 1/(m*MHz) -  MRayl \n ');
	fprintf(fid,'\n');
	tmpmedia(:,[1])=[1:length(media(:,1))]';
	tmpmedia(:,[2])=media(:,[1])*1e3;
	tmpmedia(:,[6])=media(:,[9])*1e-6;
	tmpmedia(:,[3 4 5 7 8 9 10 11 12])=media(:,[2 10 11 3 4 5 6 7 8]);
	ind = find(tmpmedia(:,7)==1);
	if ~isempty(ind)
	   tmpmedia(ind,[9 11]) = tmpmedia(ind,[9 11])/1e6;
	end
	ind = find(tmpmedia(:,7)==2);
	if ~isempty(ind)
	   tmpmedia(ind,[8 9 10 12]) = tmpmedia(ind,[8 9 10 12])*1e3;
	end
	fprintf(fid,['#%2.0f %6.2f %5.0f %6.3f %4.1f %6.3f ',...
		'    -------- Transducer -------- \n'],tmpmedia(1,1:6));
	tmpmedia = tmpmedia(2:size(tmpmedia,1),:);
	fprintf(fid,'#%2.0f %6.2f %5.0f %6.3f %4.1f %6.3f %2.0f %6.3f %6.3f %6.3f %6.3f %6.3f \n',tmpmedia');
	fprintf(fid,' \n');
	fprintf(fid,['func=1 : ',num2str(mediatxt(flagg,1)),'\n']);
	fprintf(fid,['func=2 : ',num2str(mediatxt(flagg,2)),'\n']);
	fprintf(fid,['func=6 : ',num2str(mediatxt(flagg,6)),'\n']);
	fprintf(fid,['func=7 : ',num2str(mediatxt(flagg,7)),'\n']);
	fprintf(fid,'\n');
	no = length(media(:,1)) + 1;
	if fix(flagg(6)/2)~=flagg(6)/2
	  fprintf(fid,[num2str(no),') Absorption is included [energy=energy0*exp(-alpha*freq^beta*dist)] \n']);
	else
	  fprintf(fid,[num2str(no),') Absorption is NOT included \n']);
	end
	if fix(flagg(6)/4)~=flagg(6)/4 & fix((flagg(6)-1)/4)~=(flagg(6)-1)/4
	  fprintf(fid,[num2str(no+1),...
		  ') Reflection losses are included \n']);
	else
	  fprintf(fid,[num2str(no+1),...
		  ') Reflection losses are NOT included \n']);
	end
	if fix(flagg(6)/4)
	   fprintf(fid,[num2str(no+2),...
		  ') Cosine of incident angle included \n']);
	else
	    fprintf(fid,[num2str(no+2),...
		  ') Cosine of incident angle NOT included \n']);
	end
   end
end
  fprintf(fid,'\n');
