%
% script for printing out main parameters of Bessel beam
%
% ver 1.0   9.10.96 SH
%     1.1  26.02.97 SH added more zeroes of the Bessel function
%     1.2  25.03.97 SH added max value of alpha + eq. axicon
%
% Input transducer
%       excitation
%

 disp([transtxt(transducer(18),transducer),sprintf('\n')]);
 d = transducer(1);
 N = transducer(2);
 F = transducer(9);
 lambda=media(1,2)/excitation(1);
 k = 2*pi/lambda;
 alfa = transducer(13);
 disp(['Frequency:           ',num2str(excitation(1)*1e-6),' MHz']);
 disp(['Wavelength:          ',num2str(lambda*1000),' mm, k = ',num2str(k)]);
 disp(['Number of elements:  ',num2str(N)]);
 disp(['Aperture:            ',num2str(d*1000),' mm']);
 disp(' ');
 % check that it is a Bessel beam
 
%if (transducer(18) > 3)
  disp(['Bessel beam order:   ',num2str(transducer(12))]);
  alfa_ideal = 4.81*sqrt(N)/d;
  disp(['Bessel beam alpha:   ',num2str(alfa)])
  disp(['Equivalent axicon:   ',num2str((180/pi)*asin(alfa/k)),' deg']);
  disp(['Zero at first element cut for alpha = ',num2str(alfa_ideal)]);
  alfa_max = 2*pi/lambda*2*1e-1;
%
% zeros of Bessel: first line from Bowmann: introd to Bessel Functions
% second line found numerically in Matlab:
%
  Bessel_null = [2.405, 5.520, 8.654, 11.792, 14.931, ...
	  18.071, 21.212, 24.352, 27.493];
  alfa_null = Bessel_null*2/d;
  alfa_null = alfa_null(find(alfa_null < alfa_max));
  disp('Alpha for a zero at the end of the aperture:');
  disp(sprintf('%10.3f ',alfa_null));
  disp(['Bessel beam rotation:',num2str(transducer(14))]);
  Bzmax = (d/2)*sqrt((k/alfa)^2 -1);
  disp(['Depth of field:      ',num2str(Bzmax*1000),' mm']);
  disp(['Beamwidth (-6 dB):   ',num2str(3040/alfa) ,' mm']);
  disp(['Beamwidth (0 <-> 0): ',num2str(4810/alfa) ,' mm']);
  disp(' ');


%else
  disp(' ' );
  disp('Spherically focused beam parameters:')
  if (F~=0 & ~isinf(F)),
    disp(['Fixed focus:         ',num2str(F*1000),' mm']);
    disp(['Beamwidth (-6 dB):   ',num2str(1410*lambda*F/d) ,' mm']);
    LF = lambda*(F/d)^2;
    disp(['Depth of field:      ',num2str(4*LF*1000),' mm (-1 dB)']);
    disp(['Depth of field:      ',num2str(6*LF*1000),' mm (-2 dB)']);
    disp(['Depth of field:      ',num2str(7.2*LF*1000),' mm (-3 dB)']);
  else
    disp(['Near-to-far transition (D2/4l): ', ...
	   num2str(1000*d*d/(4*lambda)),' mm']);
  end  
%end
clear d lambda k Bzmax;
return

