%------------------------------------------------------------------------
% Routine     : o2ausim       
%
% Description : Configuring observation-parameters LINE axis
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre
%
% Version no. : 3.0 VEB 05.02.93
% Version no. : 3.1 TKL 07.09.93 corrected comments
%             : 3.2 FT  08.02.94 y and t unsettable if media is 2D
%               3.3 FT  23.02.94 Removed disp('EXIT = "x"')
%               3.4 FT  20.03.94 Removed 'linjeparametre'
%               3.5 SH   6.12.94 Changed call o2ausimtxt to o2ausimt
%               3.6 SH  11.04.95 Added flagg(4)=4 for sin(theta) as axis
%               3.7 SH  14.04.95 Added conversion between coordinate systems
%                   SH  10.10.06 Added output advice on how to get an
%                                elevation scan
% Called by   : usimcnf
% Calling     : indfile, punkt, fixtxt, apobserv, o2ausimt
%------------------------------------------------------------------------

function [observasjon,option,x,y,z,t]=...
			o2ausim(observasjon,option,flagg)

fid=1;
txtcoordinates=coordtxt(flagg(4));
%
% Convert between coordinate systems
%
%
% Note that conversion between Cartesian and spherical coordinate systems
% is not clearly defined. This code gives a best attempt.
%
if flagg(4)==1
% convert to Cartesian coordinates ...
	fast=['xyzt'];
        if observasjon(14)==3
% ... from spherical
        	if option(2) == 'p', new = 'x';
        	elseif option(2) == 'h', new = 'y';
        	elseif option(2) == 'r', new = 'z';end
        elseif observasjon(14) == 4
% ... from spherical sine
		observasjon(2:3) = asin(observasjon(2:3));
		observasjon(6:7) = asin(observasjon(6:7));
        	if option(2) == 's', new = 'x';
        	elseif option(2) == 'e', new = 'y';
        	elseif option(2) == 'r', new = 'z';end
	end
        if observasjon(14)==3 | observasjon(14) == 4
	        [observasjon(1) observasjon(2) observasjon(3)]=...
        		rhp2xyz(observasjon(1),observasjon(2),observasjon(3));
         	[observasjon(5) observasjon(6) observasjon(7)]=...
        		rhp2xyz(observasjon(5),observasjon(6),observasjon(7));
	end  
elseif flagg(4)==3 
% convert to spherical coordinates ....
	fast=['rhpt'];
        if observasjon(14) == 4
% ... from spherical sine
		observasjon(2:3) = asin(observasjon(2:3));
		observasjon(6:7) = asin(observasjon(6:7));
        	if option(2) == 's', new = 'p';
        	elseif option(2) == 'e', new = 'h';end
	elseif observasjon(14) == 1
% ... from Cartesian
	        [observasjon(1) observasjon(2) observasjon(3)]=...
        		xyz2rhp(observasjon(1),observasjon(2),observasjon(3));
         	[observasjon(5) observasjon(6) observasjon(7)]=...
        		xyz2rhp(observasjon(5),observasjon(6),observasjon(7));
        	if option(2) == 'x', new = 'p';
        	elseif option(2) == 'y', new = 'h';
		elseif option(2) == 'z', new = 'r'; end
	end
elseif  flagg(4)==4
% convert to spherical sine coordinates ....
        fast=['rest'];
        if observasjon(14) == 3
% ... from spherical
		observasjon(2:3) = sin(observasjon(2:3));
		observasjon(6:7) = sin(observasjon(6:7));		
        	if option(2) == 'p', new = 's';
        	elseif option(2) == 'h', new = 'e';end
	elseif observasjon(14) == 1
% ... from Cartesian
	        [observasjon(1) observasjon(2) observasjon(3)]=...
        		xyz2rhp(observasjon(1),observasjon(2),observasjon(3));
         	[observasjon(5) observasjon(6) observasjon(7)]=...
        		xyz2rhp(observasjon(5),observasjon(6),observasjon(7));
		observasjon(2:3) = sin(observasjon(2:3));
		observasjon(6:7) = sin(observasjon(6:7));
        	if option(2) == 'x', new = 's';
        	elseif option(2) == 'y', new = 'e';
		elseif option(2) == 'z', new = 'r'; end
	end

end

if exist('new') option(2) = new;, end

option(1)='1';

com1='000';


while com1(2)~='x'
  clc

  o2ausimt;

  disp('	CHANGE 	= "number"')
  com1 = input('-> Decision (<CR> = exit): ','s');
  if isempty(com1) com1 = 'x'; end
  if length(com1)==1 com1=['0',com1];end
  if length(com1)>2 com1=['00'];end




  % Changing of parameters
  % ---------------------------------------------------------------------
  
  if com1=='01'
      temp=input('# pixels	: ');
      if ~isempty(temp) observasjon(9)=temp; end	
     
  elseif com1=='02'
    if flagg(3)~=2
        disp('Note that if an elevation profile is desired,')
        disp('then scan the azimuth angle (phi) for theta = 90 degrees')
      if flagg(4)==1
        temp=menu35('Choose axis','x','y','z','t');
      elseif flagg(4) == 3 
	temp=menu35('Choose axis','r','theta','phi','t');
      else 
	temp=menu35('Choose axis','r','sin(theta)','sin(phi)','t');
      end;
    else % layered 2D
      if flagg(4)==1
        temp=menu35('Choose axis','x','z');
      elseif flagg(4)==3
	temp=menu35('Choose axis','r','phi');
      elseif flagg(4)==4
	temp=menu35('Choose axis','r','sin(phi)');	
      end;
   end
    if isempty(temp)  
    elseif temp==1	option(2)=fast(1);ind=[1 2 3 4]; 
    elseif temp==2	option(2)=fast(2);ind=[2 1 3 4]; 
    elseif temp==3	option(2)=fast(3);ind=[3 1 2 4]; 
    elseif temp==4	option(2)=fast(4);ind=[4 1 2 3]; 
    end
    
  elseif com1=='03'
    temp=ind(1);
    observasjon(temp)=punkt(fast(temp),observasjon(temp),'start');
  elseif com1=='04'
    temp=ind(1);
    observasjon(temp+4)=punkt(fast(temp),observasjon(temp+4),'end');
  elseif com1=='05' | com1=='06' | com1=='07'
    temp=ind(str2num(com1(2))-3);
    if flagg(3)~=2 | temp==1 | temp==3
      observasjon(temp)=punkt(fast(temp),observasjon(temp),'fixed');
      observasjon(temp+4)=observasjon(temp);
    end
  end 				%change of parameters
end 					%while

if flagg(3)==2
  observasjon(2) = 0;
  observasjon(6) = 0;
end;

[x,y,z,t]=apobserv(observasjon,option,flagg);
