%------------------------------------------------------------------------
% Routine     : o3usimtx
%
% Description : Configuring observation-parameters PLANE/ QUASI-PLANE
%               txt-file
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no  : 3.0 VEB 12.05.93
%             : 3.1 TKL 30.08.93 Added dist. betw. obs. points [mm] 
%             : 3.2 TKL 23.09.93 Added dist. betw. obs. points [us]
%             : 3.3 TKL 24.11.93 Added yz-plane to PE-analysis
%             : 3.4 FT  19.01.94 Added ; after fprintf-statements
%             : 3.5 TKL 21.02.94 Added xy-plane to PE-analysis
%             : 3.6 FT  13.04.94 Removed text (# pixels..)
%             : 3.7 BJE 10.10.94 fast -> coord, commenting, changed if tests
%	      :	 		 added t init for movie, script -> function
%             : 3.8 SH  30.11.94 Added 'fid' in call and in outputs
%             : 3.9 SH   6.12.94 Shortened from o3usimtxt to o3usimtx
%             : 4.0 SH  13.12.94 Corrected small error in output of par. 9)
%             : 4.1 KE   2.05.96 Added changes to facilitate 3D observations.
%                   SH  17.08.07 more text to simplify setting of no of frames in movie 
% Called by   : o3usim
% Calling     : indfile, obstxt, coordtxt
%------------------------------------------------------------------------

function [ind]=o3usimtx(observasjon,option,flagg,excitation,coord,fid)
  
%
% observation-parameters submenu
% 
  
  fprintf(fid,'\t\t-------    OBSERVATION SUBMENU    --------- \n');
  fprintf(fid,['Option           :  ', num2str(obstxt(option)),'\n']);
  fprintf(fid,['Coordinates      :  ', num2str(coordtxt(flagg(4))),'\n']);
%  fprintf([' 1) # pixels along one axis    :  ' num2str(observasjon(9)),'\n']);
  fprintf(fid,'\n');
  
%
% initialize variable: ind (length=4; a combination of the numbers 1,2,3,4)
%
% -----------------------------------------------
% Changed here to facilitate volumetric obs  KE
% -----------------------------------------------
  if option(1)=='3' | option(1)=='f'
     ind=[1 2 3 4];
     if option(3)=='t' & option(1)=='3'
        ind(3)=4;
        ind(4)=3;
     end
  else
     ind=indfile(option(2),option(3),coord);
  end
  
%
% display current settings 1st and 2nd axis
%

% ------------------------------------
% added for volume KE 16/11
% 

  if option(1)=='3' | option(1)=='f'
     fprintf(fid,[' 2) 1. axis   :  ' num2str(coord(ind(1))),'\n']);
     tekst=fixtxt(coord(ind(1)),observasjon(ind(1)));
     fprintf(fid,[' 3) Start value of ',tekst,'\n']);
     tekst=fixtxt(coord(ind(1)),observasjon(ind(1)+4));
     fprintf(fid,[' 4) End   value of ',tekst,'\n']);
     fprintf(fid,'\n');
     fprintf(fid,[' 5) 2. axis   :  ' num2str(coord(ind(2))),'\n']);
     tekst=fixtxt(coord(ind(2)),observasjon(ind(2)));
     fprintf(fid,[' 6) Start value of ',tekst,'\n']);
     tekst=fixtxt(coord(ind(2)),observasjon(ind(2)+4));
     fprintf(fid,[' 7) End   value of ',tekst,'\n']);
     fprintf(fid,'\n');
     fprintf(fid,['12) 3. axis   :  ' num2str(coord(ind(3))),'\n']);
     tekst=fixtxt(coord(ind(3)),observasjon(ind(3)));	
     fprintf(fid,['13) Start value of ',tekst,'\n']);
     tekst=fixtxt(coord(ind(3)),observasjon(ind(3)+4));
     fprintf(fid,['14) End   value of ',tekst,'\n']);
     fprintf(fid,'\n');
%  ..... upto here...!
% --------------------------------------
  else
     fprintf(fid,[' 2) 1. axis   :  ' num2str(option(2)),'\n']);
     tekst=fixtxt(coord(ind(1)),observasjon(ind(1)));
     fprintf(fid,[' 3) Start value of ',tekst,'\n']);
     tekst=fixtxt(coord(ind(1)),observasjon(ind(1)+4));
     fprintf(fid,[' 4) End   value of ',tekst,'\n']);
     fprintf(fid,'\n');
     fprintf(fid,[' 5) 2. axis   :  ' num2str(option(3)),'\n']);
     tekst=fixtxt(coord(ind(2)),observasjon(ind(2)));
     fprintf(fid,[' 6) Start value of ',tekst,'\n']);
     tekst=fixtxt(coord(ind(2)),observasjon(ind(2)+4));
     fprintf(fid,[' 7) End   value of ',tekst,'\n']);
     fprintf(fid,'\n');
     tekst=fixtxt(coord(ind(3)),observasjon(ind(3)));	
     fprintf(fid,[' 8) Fixed value of ',tekst,'\n']);
  end
%
% display current t_start and t_stop if PLANE > MOVIE
%
% --------------------------
% checking also for 3d obs
% KE

  if option(1) == 'm' | option(1)=='f'
      tekst=fixtxt('t',observasjon(4));
      fprintf(fid,['10) Start value of ',tekst,'\n']);
      tekst=fixtxt('t',observasjon(8));
      fprintf(fid,['11) Stop  value of ',tekst,'\n\n']);
      delta_t=1/(1e3*observasjon(15)*excitation(14));	% calc from c and # obs
      % added more text 17.08.2007 SH
      fprintf(fid,'... %3.0f plots will be produced for movie (given by # obs.pts /[mm] and speed of sound)\n\n', ...
             1+(observasjon(8)-observasjon(4))/delta_t);	% nplots
    else
      tekst=fixtxt(coord(ind(4)),observasjon(ind(4)));
      fprintf(fid,[' 9) Fixed value of ',tekst,'\n']);
  end
  
%
% and # obs.pts / [mm] for PLANE and PLANE + MOVIE
%
  if exist('media')
      if all(option(2:3) == 'xz') | all(option(2:3) == 'xt') | ...
         all(option(2:3) == 'yz')           
          fprintf(fid,['15) # obs.pts /[mm] \t\t:  ', ...
                 num2str(observasjon(15)),'   dist./lambda = ', ...
                 num2str(excitation(1)/observasjon(15)/media(1,2)/1e3),'\n']);
      end         
    else
      if all(option(2:3) == 'xz') | all(option(2:3) == 'xy') ...
                 | all(option(2:3) == 'xt') | all(option(2:3) == 'yz')       
          fprintf(fid,['15) # obs.pts /[mm] \t\t:  ', ...
                 num2str(observasjon(15)),'\n']);
      end
  end
  
  fprintf(fid,'\n');
  
  
  
