%------------------------------------------------------------------------------
% Routine          : rcurved()
%
% Description      : place elements and points on surface of array.
%		     surface is 2-D rectangular and curved
%
% Language         : Matlab syntax
% Written by       : Jan Egil Kirkeb Juli 2000 
%
% Version no.      : 1.0 JEK 10.07.00
%
% Called by        : rectangu.m
% Routines called  : in_out.m
% Load files       :
%
%------------------------------------------------------------------------------

function [el_pts,centers,theta_open] = rcurved(transducer)

a=transducer(5); % Elevation array-aperture
Mm=transducer(6); % Elevation # elements
Nn=transducer(2); % Azimuth # elements
d=transducer(1); % Azimuth array-apperture
mm = transducer(7); % Elevation # points
nn = transducer(3); % Azimuth # points per element
ROC = transducer(17); % Radius of Curvature
shape = transducer(18); % Transducer shape

n = 0;
m = 0;

mmm = round(mm/Mm);

% Element spacing in azimuth direction
theta_open = 2*asin(d/(2*ROC));
disp(['Azimuth angle: ',num2str((180/pi)*theta_open),' degrees']);
d_theta = abs(theta_open)/Nn;

% Uniform element spacing in elevation dimension
d_el = a/Mm;

for az = 0:Nn-1,
   theta_center = d_theta*(-Nn/2 + 0.5 + az);
   for az_pt = 0:nn-1
      theta_delta = (d_theta/nn)*(-nn/2 + 0.5 + az_pt);
      thet = theta_center + theta_delta;
      xx = abs(ROC)*sin(thet);
      [yy,in] = in_out(xx,d/2,a/2,shape);
      for el = 0:Mm-1
         y_center = d_el*(-Mm/2 + 0.5 + el);
         if ((az_pt == 0) & (in == 1) & (abs(y_center) <= yy))
            m = m + 1;
            centers(1:5,az+1) = [abs(ROC)*sin(theta_center), y_center, ...
                  ROC*(1-cos(theta_center)), az+1, 1]';
         end % if az_pt == 0
         for el_pt = 0:mmm-1
            y_delta = y_center+(d_el/mmm)*(-mmm/2 + 0.5 + el_pt);
            
            % check that point is inside aperture contour      
            [yy, in] = in_out(xx, d/2, a/2, shape);
            if ((in == 1) & (abs(y_delta) <= yy))
               n = n + 1;
               el_pts(1,n) = xx;
               el_pts(2,n) = y_delta;
               el_pts(3,n) = sign(ROC)*(abs(ROC) - sqrt(ROC^2 - xx^2));
               el_pts(4,n) = az + 1;
               el_pts(5,n) = el + 1;
            end % if (in == 1)
         end % for el_pt = 0
      end % for el = 0
   end % for az_pt = 0
end % for az = 0