function transducer = t1usimgui(action,temp,transducer,flagg, ...
   excitation,media)
%------------------------------------------------------------------------
% Routine         : t1usimgui
%
% Description     : Configuring transducer-parameters
%			1 1/2D CURVED RECTANGULAR ARRAY
%
% Language        : Matlab 4.1
% Written by      : Vebjorn Berre, IBT
%
% Version no.     : 1.0 VEB 27.10.92 First Version
%                 : 2.0 SH  30.03.93
%                   3.0 FT  23.02.94 Removed disp('EXIT = "x"')
%                   3.1 FT  20.03.94 kerf->comments + check if choise is
%                                    legal
%                   3.2 SH   6.12.94 Changed calls: rectangular to rectangu
%                                                   t1usimtxt   to t1usimtx
%                   3.3 SH   9. 1.95 Added input of curved array parameters
%                 : 3.4 KE   2.05.96 '??' at transducer type gives a list of
%                                    options (i.e. transducer types)
%                   3.5 SH   8. 5.96 Slight modification of user interface
%                   3.6 SH  21.05.96 Changed test of input for xdcr shape
%                   3.7 SH  03.06.96 centers as output
%                   3.8 SH  15.07.96 split transducer(10:16) to t1us15d.m
%                   3.9 SH  22.05.97 Toggling of mm/lambda in transducer menu
%                   4.0 JEK 06.07.00 t1usim moved to t1usimgui, adapted to GUI
%                   4.1 SH  01.12.00 Renamed t1usimtx to t1guitx due to conflict with 
%                                    listusim
%                       SH  08.09.2006: Incorrect entering of focal lengths
%                                   in lambda

%
% Called by       : t1usim
% Routines called : rectangu, t1guitx, t1u15dtx
%------------------------------------------------------------------------

lambda=media(1,2)/excitation(1);
lambda_local=media(1,2)/excitation(1)*1e3;

tmp=size(transducer);
if tmp(2)<18 
  tmp=transducer;
  transducer=zeros([1,18]);
  transducer([1:1:length(tmp)]) = tmp;
end

% check that input is ok, else empty action
if strcmp(get(findobj('Tag',action),'Style'),'popupmenu') temp = num2str(temp); end
if isempty(temp)
   action = '';
else
   temp = str2num(temp);
   if isempty(temp) action = ''; end
end

set(findobj('Tag','MessageText'),'BackgroundColor',[0.8 0.8 0.8],'String','No message!');

if strcmp(action,'ROCmm')
   transducer(17) = temp*1e-3;
elseif strcmp(action,'ROClambda')
   transducer(17) = temp*lambda_local*1e-3;
end

curved = transducer(17) ~= 0 & finite(transducer(17));  

if strcmp(action,'dmm') transducer(1) = temp*1e-3;
elseif strcmp(action,'dlambda') transducer(1) = temp*lambda_local*1e-3;
elseif strcmp(action,'carcmm')
   arc = temp*1e-3;
   ROC = abs(transducer(17));
   transducer(1) = 2*ROC*sin(arc/(2*ROC));
elseif strcmp(action,'carclambda')
   arc = temp*lambda_local*1e-3;
   ROC = abs(transducer(17));
   transducer(1) = 2*ROC*sin(arc/(2*ROC));
elseif strcmp(action,'cang')
   ROC = abs(transducer(17));
   transducer(1) = 2*ROC*sin(pi*temp/(360));
elseif strcmp(action,'Ne_az') transducer(2) = temp;
elseif strcmp(action,'Np_az') transducer(3) = temp;
elseif (strcmp(action,'amm') | strcmp(action,'alambda'))
   if transducer(6) == 3
      set(findobj('Tag','MessageText'),'BackgroundColor',[1 0.2 0.2], ...
         'String','Change ai or ao to change total aperture!');
    elseif transducer(6) == 5
      set(findobj('Tag','MessageText'),'BackgroundColor',[1 0.2 0.2], ...
         'String','Change ai, am or ao to change total aperture!');
   else
      if strcmp(action,'amm')
         transducer(5) = temp*1e-3;
      else
         transducer(5) = temp*lambda_local*1e-3;
      end
      transducer(12) = transducer(5);
   end
elseif strcmp(action,'Me_el')
   transducer(6) = temp;
   if temp ~= 5 transducer(14) = 0; end
   if temp ~= 3 & temp ~= 5 transducer(13) = 0; end
   transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
elseif strcmp(action,'Mp_el')
   transducer(7) = temp;
elseif strcmp(action,'aimomm')
   if get(findobj('Tag','aimoMenu'),'Value') == 1 % Elevation-array aperture, inner
      transducer(12) = temp*1e-3;
      if transducer(6) == 3
         transducer(5) = 2*transducer(14)+transducer(12);
      elseif transducer(6) == 5
         transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
      end
   elseif get(findobj('Tag','aimoMenu'),'Value') == 2 % Elevation-array aperture, outer
      transducer(14) = temp*1e-3;
      if transducer(6) == 5
         transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
      elseif transducer(6) == 3
         transducer(5) = 2*transducer(14)+transducer(12);
      end
   else % Elevation-array aperture, middle
      transducer(13) = temp*1e-3;
      transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
   end
elseif strcmp(action,'aimolambda')
   if get(findobj('Tag','aimoMenu'),'Value') == 1 % Elevation-array aperture, inner
      transducer(12) = temp*lambda_local*1e-3;
      if transducer(6) == 5
         transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
      elseif transducer(6) == 3
         transducer(5) = 2*transducer(14)+transducer(12);
      end
   elseif get(findobj('Tag','aimoMenu'),'Value') == 2 % Elevation-array aperture, outer
      transducer(14) = temp*lambda_local*1e-3;
      if transducer(6) == 5
         transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
      elseif transducer(6) == 3
         transducer(5) = 2*transducer(14)+transducer(12);
      end
   else % Elevation-array aperture, middle
      transducer(13) = temp*lambda_local*1e-3;
      transducer(5) = 2*transducer(14)+transducer(12)+2*transducer(13);
   end
elseif strcmp(action,'rimomm')
   if get(findobj('Tag','rimoMenu'),'Value') == 1 % Elevation Fixed focus, inner
      transducer(9) = temp*1e-3;
   elseif get(findobj('Tag','rimoMenu'),'Value') == 2 % Elevation Fixed focus, outer
      transducer(11) = temp*1e-3;
   else % Elevation Fixed focus, middle
      transducer(10) = temp*1e-3;
   end
elseif strcmp(action,'rimolambda')
   if get(findobj('Tag','rimoMenu'),'Value') == 1 % Elevation Fixed focus, inner
% 08 Sep 2006: forgotten to multiply by lambda_local
      transducer(9) = temp*lambda_local*1e-3;
   elseif get(findobj('Tag','rimoMenu'),'Value') == 2 % Elevation Fixed focus, outer
% 08 Sep 2006: forgotten to multiply by lambda_local
      transducer(11) = temp*lambda_local*1e-3;
   else % Elevation Fixed focus, middle
% 08 Sep 2006: forgotten to multiply by lambda_local
       transducer(10) = temp*lambda_local*1e-3;
   end
elseif strcmp(action,'omomm')
   if get(findobj('Tag','omoMenu'),'Value') == 1 % Elevation offset, outer
      transducer(16) = temp*1e-3;
   else % Elevation offset, middle
      transducer(15) = temp*1e-3;
   end
elseif strcmp(action,'omolambda')
   if get(findobj('Tag','omoMenu'),'Value') == 1 % Elevation offset, outer
      transducer(16) = temp*lambda_local*1e-3;
   else % Elevation offset, middle
      transducer(15) = temp*lambda_local*1e-3;
   end
elseif (strcmp(action,'ShapeEdit') & temp >= 0)
   transducer(18) = temp;
elseif strcmp(action,'ShapeMenu')
   if temp == 1 transducer(18) = 0; % Rectangular Transducer
   elseif temp == 2 transducer(18) = 2; % Elliptical Transducer
   elseif temp == 3 transducer(18) = 2.5; % Superelliptical Transducer
   elseif temp == 4 transducer(18) = -8; % Octagonal Transducer
   elseif temp == 5 transducer(18) = -2; % Mills Cross Type II
   elseif temp == 6 transducer(18) = -1; % Mills Cross Type I
   end
end

t1guitx(transducer, lambda);
if (transducer(6) == 3 | transducer(6) == 5) t1u15dtx(transducer, lambda); end