%------------------------------------------------------------------------
% Routine         : t1usimtx
%
% Description     : Configuring transducer-parameters - txt-file
%			 CURVED AND RECTANGULAR ARRAY
% Language        : Matlab 4.0
% Written by      : Vebjorn Berre 12/5-93
% Version no.     : 1.0
% Version no.     : 1.1 TKL 14.07.93 Replaced the lambda_local printout
% Version no.     : 1.2 SH  10.09.93 Changed format for output of transducer type
%                   1.3 SH   2.12.93 Corrected line for elevation # points
%                   1.4 SH  25.02.94 2D array
%                   1.5 FT  20.03.94 Changed text 1.5D + kerf->comment
%                   1.6 SH   6.12.94 Shortened from t1usimtxt to t1usimtx
%                   1.7 SH   9. 1.95 Added output of curved array parameters
%                   1.8 SH  16.03.95 Simplified label of menu
%                   1.9 SH  11.05.95 Included decimals in format for transducer(18) 
%                   2.0 SH  15.07.96 split 1.5 d setup to t1u15dtx.m
%                   2.1 SH  15.05.97 Improved output of arc-length
%                   2.2 SH  22.05.97 Toggling of mm/lambda in transducer menu 
%                       SH  01.12.00 Called only by listusim, no longer by t1usim
%                   
% Called by       : listusim
% Routines called : t1u15dtx
%------------------------------------------------------------------------

  fprintf(fid,'\n');
  fprintf(fid,'\t-----                    TRANSDUCER SUBMENU                 ------- \n');
  fprintf(fid,'\t-----                 RECTANGULAR AND CURVED ARRAY          ------- \n');
  fprintf(fid,'\n');
  if length(flagg) > 4
    if flagg(5)==1 
      fprintf(fid,['0) toggle \t\t    Input is in [mm] units \n']);
    elseif flagg(5)==2 
      fprintf(fid,['0) toggle \t\t    Input is in [lambda] units \n']);
    end
  else
      fprintf(fid,['0) toggle \t\t    Input is in [mm] units \n']);
  end
  fprintf(fid,['\t\t\t       lambda = ',num2str(lambda*1e3),' mm \n']);

fprintf(fid,'\n');
fprintf(fid,'18) Transducer footprint (0-rect., 2-ellipse) \t= %7.2f \n',transducer(18));

fprintf(fid,'17) Radius of curvature (0-planar, <0-curved) \t= %7.2f mm = %7.2f lambda \n',transducer(17)*1e3,transducer(17)/lambda);
curved = transducer(17) ~= 0 & finite(transducer(17));  
fprintf(fid,'\n');
fprintf(fid,' AZIMUTH:\n');
if curved,
  fprintf(fid,'1) Azimuth array-aperture (chord)\t d \t= %7.2f mm = %7.2f lambda \n',transducer(1)*1e3,transducer(1)/lambda);
  ROC = abs(transducer(17));
  arc = ROC*2*asin(transducer(1)/(2*ROC));
  fprintf(fid,'28)Curved array arc \t\t\t\t= %7.2f mm = %7.2f lambda \n',arc*1000, arc/lambda);
  fprintf(fid,'29)Curved array angle \t\t\t\t= %7.2f deg \n',180*arc/(pi*ROC));
else
  fprintf(fid,'1) Azimuth array-aperture \t\t d \t= %7.2f mm = %7.2f lambda \n',transducer(1)*1e3,transducer(1)/lambda);
end
fprintf(fid,'2) Azimuth # elements \t\t\t Ne_az \t= %4.0f  \n',transducer(2));
fprintf(fid,'3) Azimuth # points per element \t Np_az \t= %4.0f \n',...
    transducer(3));

%
%fprintf(fid,'4) Azimuth kerf \t\t\t ak \t= %7.2f micro \n',transducer(4)*1e6);
%
fprintf(fid,'\n');


if (transducer(6)~=3 & transducer(6)~=5)

  tmpstr = '5) Elevation array-aperture';
  if transducer(6)==1
    fprintf(fid,' ELEVATION (1-D):\n');
    tmpstr = [tmpstr,'  \t\t a \t= %7.2f mm = %7.2f lambda \n'];
  else
    fprintf(fid,' ELEVATION (2-D):\n');
    tmpstr = [tmpstr,'\t\t a \t= %7.2f mm = %7.2f lambda \n'];
  end
  fprintf(fid,tmpstr,transducer(5)*1e3,transducer(5)/lambda);


  fprintf(fid,'6) Elevation # elements \t\t Me_el\t= %4.0f  \n',transducer(6));
  fprintf(fid,'7) Elevation # points   \t\t Mp_el \t= %4.0f  \n',transducer(7));
%
%fprintf(fid,'8) Elevation kerf \t\t\t bk \t= %7.2f micro \n',...
%    transducer(8)*1e6);
%
  fprintf(fid,['9) Elevation Fixed focus \t\t ri (F) = ',...
	  '%7.2f mm = %7.2f lambda \n'],...
          transducer(9)*1e3,transducer(9)/lambda);

else
  ok = t1u15dtx(transducer,lambda,fid); % 1.5 d array

  if ~exist('ok'), % if a dummy routine was called for t1u15dtx, default to 1-d array
        disp('1.5 d not available, default is 1d array')
	transducer(6) = 1;
  end
end

fprintf(fid,'\n');






