%------------------------------------------------------------------------
% Routine     : movetxt.m
%
% Description :  This is a callback designed to be called by a
%                WindowButtonDown event.  COMMAND dictates the
%                function's behavior. Basically, the function 
%                handles mouse-controlled movement and rotation
%                of text.
%
% Language    : Matlab 4.1
% Written by  : Keith Rogers (Transferred from the Mathworks ftp-site)
%
% Version no. : 1.0 KR 30.11.93 First version
%             : 2.0 FT 11.02.94 made compatible with Ultrasim-plottool
%                   27.09.06 SH renamed gco to gcous to avoid conflict
%                   with toolbox/matlab/graphics/gco.m
%
% Called by   : textfunc
% Calling     : isobj
%------------------------------------------------------------------------

function movetxt(command)

global  movetxt_pos
global oldtextobj;

if(command < 3)	  % If we're setting up a buttondown funtion

	%%%%%%%%%%%%%%%%%%%%%%%
	% De-select old objects
	%%%%%%%%%%%%%%%%%%%%%%%

	if(oldtextobj ~= gcous)
		if(isobj(oldtextobj))
			set(oldtextobj,'Selected','off');
		end
	end


	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Make sure we are dealing with a text object
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	if(strcmp(get(gcous,'Type'),'text')),
		set(gcous,'Selected','on');
		oldtextobj = gcous;
		set(gcous,'EraseMode','xor','Selected','on');

	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Set up functions for a text move
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

		if(command == 1)
			set(gcous,'UserData',get(gcous,'units'));
			set(gcous,'units','data');
			set(gcf,'WindowButtonMotionFcn','movetxt(7)');
			set(gcf,'WindowButtonUpFcn','movetxt(6)');

	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Set up functions for a text rotate
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

		elseif(command == 2)

      	%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      	% Icky coordinate transforms 
      	%%%%%%%%%%%%%%%%%%%%%%%%%%%%

			set(gcous,'UserData',get(gcous,'units'));
			oldunits = get(gcous,'Units');
			set(gcous,'Units','normalized');
			axpos = get(gca,'position');
			txtpos = get(gcous,'position');
			txtext = get(gcous,'extent');
			set(gcous,'Units',oldunits);
			movetxt_pos(1) = axpos(1)+axpos(3)*txtpos(1);
			movetxt_pos(2) = axpos(2)+axpos(4)*txtpos(2);
			ext(1) = axpos(1)+axpos(3)*txtext(1);
			ext(2) = axpos(2)+axpos(4)*txtext(2);
			ext(3) = axpos(3)*txtext(3);
			ext(4) = axpos(4)*txtext(4);
			set(gcf,'units','normalized');
			currpos = get(gcf,'currentpoint');

      	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      	% Only activate if we're clicking inside
		% the bounds of the text's box.
      	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

			if(currpos(1) > ext(1) & currpos(1) < ext(1)+ext(3)...
			&  currpos(2) > ext(2) & currpos(2) < ext(2)+ext(4))
			set(gcf,'WindowButtonMotionFcn','movetxt(5)',...
			'WindowButtonUpFcn','movetxt(6)');
				set(gcous,'erasemode','xor');
			end
		end
	end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do the rotate (this is for WindowButtonMotionFcn) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

elseif(command == 5)
		currpos = get(gcf,'currentpoint');
		theta=180/pi*atan2(currpos(2)-movetxt_pos(2),currpos(1)-movetxt_pos(1));
		set(gcous,'rotation',theta);

%%%%%%%%%%%%%%%%%%%%
% WindowButtonUpFcn 
%%%%%%%%%%%%%%%%%%%%

elseif(command == 6)
			set(gcous,'units',get(gcous,'UserData'));
			set(gcous,'erasemode','normal');
			set(gcf,'WindowButtonMotionFcn','');
			set(gcf,'WindowButtonUpFcn','');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do the Text Move (this is for WindowButtonMotionFcn) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

elseif(command == 7)
	p = get(gca,'CurrentPoint');
	set(gcous,'Position',[p(1,1) p(1,2) p(1,3)]);
end
