function plotfig=plottool(ACTION,num);
  
%------------------------------------------------------------------------
% Function    : plotfig = plottool(ACTION,num);
% Description : Controls the GUI of the PLOT window, depending on the 
%               ACTION parameter.
%
% In:  ACTION   'initialize'        initialize config window, equals the old 
%                                   usimcnf-file. 
%
%               'update_colormap'   update colormap checking   
%
%               'update_shading'    update shading checking
%
%                                                             -BJE 25.04.95
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no. : 1.0 VEB 08.12.92
% Version no. : 3.0 VEB 27.04.93 
% Version no. : 3.1 TKL 14.09.93 Calling plottool when closing plotfig
% Version no. : 3.2 TKL 15.09.93 Removed close screen, added clear_screen
% Version no. : 3.3 TKL 21.09.93 Added colormap to menu
% Version no. : 3.4 TKL 05.10.93 Corrected misspelling in colormap
% Version no. : 3.5 TKL 22.11.93 Changed CleanUpScreen call to cleanscr
%                                Changed SetColorMap call to setcomap
%               3.6 SH  21.12.93 Added choice of shading to menu
%               4.0 FT  10.02.94 Reorganized Plottool
%               4.1 FT  21.02.94 included plotfig in text-menu command
%               4.2 SH  23.11.94 Changed menubar option (for PC compatibility)
%               4.3 BJE 25.04.95 Reorganized file, script -> function , smoother GUI
%               4.4 BJE 10.05.95 Removed setcomap, setshade from
%               'initialize'
%               4.5 SH  22.05.95 Added menu for readout of value in plot
%               4.6 KE/SH 14.10.96 New choice in Option menu, with 'visualize'
%                   11 oct06 np (Niall Parker) include 'd' delimiter 
%
%
% Called by   : ultrasim, setcomap, setshade
% Calling     : cleanscr, setcomap, setshade, zoomusim, saveres, loadres, setlabel,
%               textfunc, plottool
%------------------------------------------------------------------------
  
  
  
% ********************************************************
%
% 			ACTION 'initialize'
%
% ********************************************************
  
  if strcmp(ACTION,'initialize')
      plotfig=figure('name','ULTRASIM - PLOT','numbertitle','off',...
          'units','normalized','position',[0,0.07,0.49,0.4],...
          'Visible','off','Backingstore','off','menubar','none');
      
      
%
% MENUBAR: File
%
      
      tmpobj=uimenu(plotfig,'Label','File');
      
      uimenu(tmpobj,'Label','Save Results','callback','saveres')
       % add delimiter between usr directory and filename  np 11oct06
      uimenu(tmpobj,'Label','Load Results','callback','loadres(plotfig,usr_resdir,d)')
      
      
%
% MENUBAR: Axis
%
      
      tmpobj=uimenu(plotfig,'label','Axis','Callback','setlabel');
      
      uimenu(tmpobj,'label','','callback',...
          ['tmp = get(gcm,''label'');',...
          'if strcmp(tmp(6:7),''On''),',...
          'axis on;else;axis off;end;']);
      tmpobj2 = uimenu(tmpobj,'label','X-Axis');
      uimenu(tmpobj2,'label','','callback',...
          ['tmp = get(gcm,''label'');'...
          'if strcmp(tmp(1:2),''Li''),'...
          'set(gca,''XScale'',''linear'');'...
          'else,'...
          'set(gca,''XScale'',''log'');'...
          'end;']);
      tmpobj2 = uimenu(tmpobj,'label','Y-Axis');
      uimenu(tmpobj2,'label','','callback',...
          ['tmp = get(gcm,''label'');'...
          'if strcmp(tmp(1:2),''Li''),'...
          'set(gca,''YScale'',''linear'');'...
          'else,'...
          'set(gca,''YScale'',''log'');'...
          'end;']);
      tmpobj2 = uimenu(tmpobj,'label','Z-Axis');
      uimenu(tmpobj2,'label','','callback',...
          ['tmp = get(gcm,''label'');'...
          'if strcmp(tmp(1:2),''Li''),'...
          'set(gca,''ZScale'',''linear'');'...
          'else,'...
          'set(gca,''ZScale'',''log'');'...
          'end;']);
      tmpobj2 = uimenu(tmpobj,'label','Format','Separator','on');
      uimenu(tmpobj2,'label','equal','callback','axis equal');
      uimenu(tmpobj2,'label','square','callback','axis square');
      uimenu(tmpobj2,'label','normal','callback','axis normal');
      tmpobj2 = uimenu(tmpobj,'label','Zoom','Separator','on');
      uimenu(tmpobj2,'label','Zoom In','callback','zoomusim;');
      uimenu(tmpobj2,'label','Zoom Out','callback','axis auto');
      
      
%
% MENUBAR: Options
%
      
      tmpobj=uimenu(plotfig,'label','Options','callback','setlabel;');
      
      uimenu(tmpobj,'label','PlotSetup','Callback', ...
	'[visualize]=setvisu(option,flagg,visualize);');
      uimenu(tmpobj,'label','','callback','grid;');
      uimenu(tmpobj,'label','','callback','hold;');
%      tmpobj2=uimenu(tmpobj,'label','Plot Setup','Callback',...
%	'[visualize]=setvisu;');
      
      
%
% MENUBAR: Text
%
      
      TextMenu = uimenu(plotfig,'Label','Text');
      FontMenu = uimenu(TextMenu,'Label','Font');
      StyleMenu = uimenu(TextMenu,'Label','Style');
      SizeMenu = uimenu(TextMenu,'Label','Size');
      
% Font Menu
      
      uimenu(FontMenu,'Label','Avant Garde', ...
          'Callback','textfunc(1,''Avant Garde'')');
      uimenu(FontMenu,'Label','Bookman', ...
          'Callback','textfunc(1,''Bookman'')');
      uimenu(FontMenu,'Label','Courier', ...
          'Callback','textfunc(1,''Courier'')');
      uimenu(FontMenu,'Label','Helvetica', ...
          'Callback','textfunc(1,''Helvetica'')');
      uimenu(FontMenu,'Label','Helvetica Narrow', ...
          'Callback','textfunc(1,''Helvetica Narrow'')');
      uimenu(FontMenu,'Label','New Century Schoolbook', ...
          'Callback','textfunc(1,''New Century Schoolbook'')');
      uimenu(FontMenu,'Label','Palatino', ...
          'Callback','textfunc(1,''Palatino'')');
      uimenu(FontMenu,'Label','Symbol', ...
          'Callback','textfunc(1,''Symbol'')');
      uimenu(FontMenu,'Label','Times', ...
          'Callback','textfunc(1,''Times'')');
      uimenu(FontMenu,'Label','Zapf Chancery', ...
          'Callback','textfunc(1,''Zapf Chancery'')');
      uimenu(FontMenu,'Label','Zapf Dingbats',...
          'Callback','textfunc(1,''Zapf Dingbats'')');
      
% Style Menu
      
      uimenu(StyleMenu,'Label','Plain','Callback','textfunc(4,''plain'')');
      uimenu(StyleMenu,'Label','Italic','Callback','textfunc(2,''italic'')');
      uimenu(StyleMenu,'Label','Oblique','Callback','textfunc(2,''oblique'')');
      uimenu(StyleMenu,'Label','Light','Callback','textfunc(3,''light'')');
      uimenu(StyleMenu,'Label','Demi','Callback','textfunc(3,''demi'')');
      uimenu(StyleMenu,'Label','Bold','Callback','textfunc(3,''bold'')');
      
% Size Menu
      
      uimenu(SizeMenu,'Label','6','Callback','textfunc(5,6)');
      uimenu(SizeMenu,'Label','9','Callback','textfunc(5,9)');
      uimenu(SizeMenu,'Label','12','Callback','textfunc(5,12)');
      uimenu(SizeMenu,'Label','14','Callback','textfunc(5,14)');
      uimenu(SizeMenu,'Label','18','Callback','textfunc(5,18)');
      uimenu(SizeMenu,'Label','24','Callback','textfunc(5,24)');
      uimenu(SizeMenu,'Label','Other','Callback','textfunc(5,0)');
      
      uimenu(TextMenu,'Label','Add Text','Separator','on','Callback','textfunc(10,0)');
      uimenu(TextMenu,'Label','Alter Text','Callback','textfunc(9,0)');
      
%  Move Text
      
      Move_Text = uimenu(TextMenu,'Label','Move','Separator','on','Callback',...
          'textfunc(6,0)','Accelerator','M','Checked','off');
      
%  Rotate Text
      
      Rotate_Text = uimenu(TextMenu,'Label','Rotate','Callback',...
          'textfunc(7,0)','Accelerator','R','Checked','off');
      
      TextUserData = [Move_Text;Rotate_Text];
      set(TextMenu,'UserData',TextUserData);
      
% Delete Text objext
      
      uimenu(TextMenu,'Label','Delete','Callback','textfunc(8,0)',...
          'Separator','on','Accelerator','D');
      
      
%
% MENUBAR: Print
%
      
      tmpobj=uimenu(plotfig,'label','Print');
      
      uimenu(tmpobj,'label','to PRINTER',...
          'callback','print');
      uimenu(tmpobj,'label','to PostScript file',...
          'callback','print -deps usimtemp');
      uimenu(tmpobj,'label','to PostScript file (Color)',...
          'callback','print -depsc usimtemp');
      uimenu(tmpobj,'label','APPEND to PostScript file',...
          'callback','print -deps -append usimtemp');
      
      
%
% MENUBAR: Clear
%
      
      tmpobj=uimenu(plotfig,'label','Clear');
      
      uimenu(tmpobj,'label','Reset Screen',...
          'callback',['close(plotfig);','plotfig=plottool(''initialize'');',...
          'plotfigOrigHandle=get(plotfig,(''children''));']);
      uimenu(tmpobj,'label','Clear Screen',...
          'callback','cleanscr(plotfig,plotfigOrigHandle);');
      uimenu(tmpobj,'label','Reset Plots','Separator','on',...
          'callback','subplot(1,1,1);');
      
      
%
% MENUBAR: Subplot
%
      
      tmpobj=uimenu(plotfig,'label','Subplot');
      uimenu(tmpobj,'label','(1,1,1)',...
          'callback','subplot(1,1,1)');
      tmpobj2=uimenu(tmpobj,'label','(2,1)');
      uimenu(tmpobj2,'label','(2,1,1)',...
          'callback','subplot(2,1,1)');
      uimenu(tmpobj2,'label','(2,1,2)',...
          'callback','subplot(2,1,2)');
      tmpobj2=uimenu(tmpobj,'label','(1,2)');
      uimenu(tmpobj2,'label','(1,2,1)',...
          'callback','subplot(1,2,1)');
      uimenu(tmpobj2,'label','(1,2,2)',...
          'callback','subplot(1,2,2)');
      tmpobj2=uimenu(tmpobj,'label','(1,3)');
      uimenu(tmpobj2,'label','(1,3,1)',...
          'callback','subplot(1,3,1)');
      uimenu(tmpobj2,'label','(1,3,2)',...
          'callback','subplot(1,3,2)');
      uimenu(tmpobj2,'label','(1,3,3)',...
          'callback','subplot(1,3,3)');
      tmpobj2=uimenu(tmpobj,'label','(2,2)');
      uimenu(tmpobj2,'label','(2,2,1)',...
          'callback','subplot(2,2,1)');
      uimenu(tmpobj2,'label','(2,2,2)',...
          'callback','subplot(2,2,2)');
      uimenu(tmpobj2,'label','(2,2,3)',...
          'callback','subplot(2,2,3)');
      uimenu(tmpobj2,'label','(2,2,4)',...
          'callback','subplot(2,2,4)');
      
      
%
% MENUBAR: Colormap
%
      
%
% Checking the actual submenu is moved to setcomap.m
%
      tmpobj = uimenu(plotfig,'Label','Colormap');
      h_colormap(1)=uimenu(tmpobj,'Label','bone','Callback','setcomap(plotfig,1);');
      h_colormap(2)=uimenu(tmpobj,'Label','gray','Callback','setcomap(plotfig,2);');
      h_colormap(3)=uimenu(tmpobj,'Label','pink','Callback','setcomap(plotfig,3);');
      h_colormap(4)=uimenu(tmpobj,'Label','copper','Callback','setcomap(plotfig,4);');
      h_colormap(5)=uimenu(tmpobj,'Label','cool','Callback','setcomap(plotfig,5);');
      h_colormap(6)=uimenu(tmpobj,'Label','hot','Callback','setcomap(plotfig,6);'); 
      h_colormap(7)=uimenu(tmpobj,'Label','hsv','Callback','setcomap(plotfig,7);'); 
      h_colormap(8)=uimenu(tmpobj,'Label','jet','Callback','setcomap(plotfig,8);'); 
      h_colormap(9)=uimenu(tmpobj,'Label','prism','Callback','setcomap(plotfig,9);'); 
      h_colormap(10)=uimenu(tmpobj,'Label','flag','Callback','setcomap(plotfig,10);'); 
      h_colormap(11)=uimenu(tmpobj,'Label','red','Callback','setcomap(plotfig,11);'); 
      h_colormap(12)=uimenu(tmpobj,'Label','green','Callback','setcomap(plotfig,12);'); 
      h_colormap(13)=uimenu(tmpobj,'Label','blue','Callback','setcomap(plotfig,13);'); 
      h_colormap(14)=uimenu(tmpobj,'Label','white','Callback','setcomap(plotfig,14);'); 
      h_colormap(15)=uimenu(tmpobj,'Label','black','Callback','setcomap(plotfig,15);');
      
%
% MENUBAR: Shading
%
      
      tmpobj = uimenu(plotfig,'Label','Shading');
      h_shading(1)=uimenu(tmpobj,'Label','faceted','Callback','setshade(plotfig,1);');
      h_shading(2)=uimenu(tmpobj,'Label','flat','Callback','setshade(plotfig,2);');
      h_shading(3)=uimenu(tmpobj,'Label','interpolated','Callback',...
          'setshade(plotfig,3);');
%
% MENUBAR: Readout
%
%      
%      tmpobj = uimenu(plotfig,'Label','Readout','Callback', ...
%	  'disp(''Point mouse to point in plot and press button'');[x,y]=ginput(1)');
%               
      
%
% Clean variablespace
%      
      
      clear tmpobj tmpobj2 TextMenu FontMenu StyleMenu 
      clear TextUserData SizeMenu Move_Text Rotate_Text
      
      
%
% HANDLES
%
% Put handles in current figure's (plotfig) UserData. 
% NB! When adding new handles to the list, append them after the last
% existing handle, or you have to update all references to h_list 
% (Routines depend on the handle index)
%
      
      h_list=[ h_colormap ... 		% 15 handles - 1:15
          h_shading];			% 3 handles  - 16:18
      
      
%
% Store h_list in UserData, make window visible
% Restore backing (turned off during initilize for speed) 
%
      
      set(plotfig,'UserData',h_list,'Backingstore','on','Visible','on');
      
      
%
% Set default mousebutton function
%
      
      set(plotfig,'WindowButtonDownFcn','tselusim');	% Set mosebuttonfunction
      
  end;  % if ACTION 'initialize'


  
% ********************************************************
%
% 			ACTION 'update_colormap'
%
% ********************************************************
  
  
  if strcmp(ACTION,'update_colormap')
      
      plotfig=findobj('Name','ULTRASIM - PLOT');
      h_list=get(plotfig,'UserData');		% get calcresp handles
      h_colormap=h_list(1:15);			% put actual handles in vector
      
      set(h_colormap,'checked','off');		% uncheck all
      set(h_colormap(num),'checked','on');	% check actual
      
  end;  % ACTION 'update_colormap'
  
  
  
% ********************************************************
%
% 			ACTION 'update_shading'
%
% ********************************************************
  
  
  if strcmp(ACTION,'update_shading')
      
      plotfig=findobj('Name','ULTRASIM - PLOT');
      h_list=get(plotfig,'UserData');		% get calcresp handles
      h_shading=h_list(16:18);			% put actual handles in vector
      
      set(h_shading,'checked','off');		% uncheck all
      set(h_shading(num),'checked','on');	% check actual
      
  end;  % ACTION 'update_shading'
  
  
  
  
