%------------------------------------------------------------------------
% Routine         : functxt        
%
% Description     : Returns information on the type of function being
%		    used in a layered model.
%
% Language        : Matlab 4.1
% Written by      : Frode Teigen (IBT)
%
% Version no.     : 1.0 FT 07.01.94
%		  : 1.5 FT 02.02.94 Added function class 5
%                   1.6 EH 27.11.95 Added function class 6 and 
%                                   fixed h(x) -> h(x,y) for 3D
%                   1.7 EH 19.02.96 Added function class 7
%     
% Called by       : musim
% Routines called : none
%------------------------------------------------------------------------

function Y=functxt(flagg,functype)

if flagg(3)==2
   if functype==1
    	Y=[' h(x) = ax + bx^2 + cx^3 + dx^4 \n',...
	   '  z   = h(x) + depth of layer \n'...
	  ' x and h(x) are calculated in mm,\n',...
	  ' and coefficients b, c & d should be given accordingly'];
    elseif functype==2
	Y=[' h(x) = c*b*(1 - sqrt( 1 - (x/a)^2 ))  when abs(x) <= a \n'...
	' h(x) = (b + d)*c                      when abs(x) > a \n'...
	   '  z   = h(x) + depth of layer'];
    elseif functype==3
	Y=['sirkel transduceren'];
    elseif functype==4
	Y=[' a/b total "radii" in x/z-direction \n',...
           ' c is "radius" in x-direction without smoothing ( a-b<c<a ) \n'...
 	   ' d = -1/0/1 when smoothing lower/both/upper corner'];
    elseif functype==5
	Y = [' If a = 1 the user-defined boundary must be'...
	   ' named ''bound1''\n'...
	   ' (a = 2 => ''bound2'' etc.). \n You have to declare the variable'...
	   ' as global by writing : \n ''global bound1'', before using the'...
	   ' boundary. \n \n'...
	   '  x   = bound1(1,:) [mm] \n'...
	   ' h(x) = bound1(2,:) [mm] \n'...
	   '  z   = h(x) + depth of layer \n \n'...
	   ' b : Interpolation Method \n'...
	   '     1 : Linear Interpolation \n'...
	   '     2 : Cubic Spline Interpolation'];
    end
elseif flagg(3)==3
    if functype==1
    	Y=[' h(x,y) = ax + bx^2 + cy + dy^2 \n'...
	   '  z   = h(x,y) + depth of layer \n'...
	  ' x, y and h(x,y) are calculated in mm,\n',...
	  ' and coefficients b & d should be given accordingly'];
    elseif functype==2
	Y=[' h(x,y) = d*c*(1-sqrt(1-(x/a)^2-(y/b)^2))'...
	   ' when (x/a)^2+(y/b)^2<=1 \n'...
	   ' h(x) = c*d                             when (x/a)^2+(y/b)^2>1'...
	   '\n  z   = h(x) + depth of layer \n'];
    elseif functype==6 
        Y=[' h(x,y) = d*s_a(e*x-b,e*y-c) \n' ...
           ' The mesh defining s_a must be stored in globa| \n' ...
           ' varable "surfaces".\n' ...
	   '  z   = h(x,y) + depth of layer \n' ...
           'Enter all lengths in mm.\n'];
    elseif functype==7
        Y=[' h(x,y) = e*X(2*pi*c*x/a)*cos(pi*x/a)*Y(2*pi*d*y/b)*cos(pi*y/b) ,\n'...
           '          when -a/2 < x < a/2 and -b/2 < y < b/2,\n'...
           '        = 0 ,  elsewhere. \n' ...
           '        X() = sin() when 2*c is even integer,\n '...
           '        X() = cos() when 2*c is odd integer. \n '...
           '        Y() = sin() when 2*d is even integer,\n '...
           '        Y() = cos() when 2*d is odd integer. \n '...
           'Enter all lengths in mm.\n'];
    end
end

