%------------------------------------------------------------------------
% Routine        : viewtrsd.m
%
% Description    : View of transducer
%
% Language       : Matlab syntax
% Written by     : Vebjorn Berre, Sverre Holm 19.3.93
% Version no.    : 3.0
% Date           : 14.4.93  SH  
%	           14.2.94  JOE changed to include 2D-arrays (noncurved)  
%	           14.4.94  JOE Exclude thinned elem_pts and disabled yz-plot
%                           for linear arrays.
%                  10.04.95 SH Added element cuts for 32x1 array, increased
%                           annular array resolution, improved aspect ratios
%                  14.04.95 SH Oops removed too much ... added plot of
%                           element centers (rectangular array)
%                  18.04.95 SH Corrected error in scaling of annular array
%                              plot
%                  18.05.95 SH Visible x-es in 2D transducer plot
%                  07.12.95 SH Corrected no of subplots for curved transducer
%                              and new option for single plot only
%                  27.01.97 SH Conical circular transducer
%                  04.06.97 SH Matlab 5: Initialized x_ok, y_ok
%                  10.06.97 SH Colors in plots in variables 
%                  18.01.00 SH Modified logical statement to avoid warning in ver 5.3
%                  24.05.00 SH Plots points of annular array always
%                  22.08.00 SH gives no of active elements for 2D arrays
% 
% Called by      : usimcnf, thinning
% Routines called: hein.m
% Load files     : none
%
% Purpose:	  plot 2D views of rectangular, curved and elliptic transducer
%                 and circular transducer
%------------------------------------------------------------------------
%
function Y=viewtrsd(transducer,elem_pts,flagg,no_plots)
%
% no_plots - 0 or does not exist => automatic setting of no of subplots from
%              transducer type
%            1 only a single plot
%
%c1 = 'y';  % color of outline
c1 = 'b';  % color of outline
c2 = 'r';  % color of points
c3 = 'g*'; % color and point type for points
c4 = 'g.'; % color and point type for many points
%c5 = 'c+'; % color for 2D array
c5 = 'g+'; % color for 2D arrays
%c6 = 'm' ; frame for 2D array
c6 = c1;  
  
a=transducer(5);
ao=transducer(14);
am=transducer(13);
d=transducer(1);
ri = transducer(9);
rm = transducer(10);
ro = transducer(11);
Mm=transducer(6);
Nn=transducer(2);
ROC = transducer(17);
shape = transducer(18);

%--------------------------------------------------------------------------
% JOE 14.04.94
thinned = find(elem_pts(4,:) < 0);
elem_pts(:,thinned) = [];
%
%----------------------
if exist('no_plots') 
  no_sub = no_plots;
else
  no_sub=0;
end
x_ok = 1;
y_ok=1;
if flagg(2) == 1,

%
% 1,1.5,2-D, planar/curved, rectangular/oval transducer
%


if (shape > 0),
	[x_ok, y_ok] = hein(d/2, a/2, shape, 10*Nn*transducer(3), 0);
end
%
% plot array geometry, SH 10 June 1992:
% 
       cond1 = (finite(ri) & ri ~= 0);
       cond3 = (finite(rm) & rm ~= 0);
       cond5 = (finite(ro) & ro ~= 0);
       if ((Mm == 3 & cond1 & cond3)|(Mm == 5 & cond1 & cond3 & cond5)|(ROC~=0))
	  no_sub = 2;
       else
	  no_sub = 1;
       end	  

subplot(no_sub,1,1)       
% -------------------------------------------


%	Kari Lervik. 09.10.92. Making a plot of the array with points.
%------------------------------------------------------------------------
if (Mm == 1) | (Mm == 3) | (Mm == 5),	
	d1 = d * 1000;
	a1 = a * 1000;
        x1 = [-d1/2,d1/2,d1/2,-d1/2,-d1/2];
	y1 = [-a1/2,-a1/2,a1/2,a1/2,-a1/2];
	x2 = 0;
	y2 = 0;
	x3 = 0;
	y3 = 0;
% make a drawing of the array's elevation cuts
%------------------------------------------------------------------------
	if Mm == 3,
        	x2 = [-d1/2,d1/2,d1/2,-d1/2];
   		y2 = [a1/2-1000*ao,a1/2-1000*ao,-a1/2+1000*ao,-a1/2+1000*ao];
	elseif Mm == 5,
 		x2 = [-d1/2,d1/2,d1/2,-d1/2,-d1/2,d1/2,d1/2,-d1/2];
		y2 = [a1/2-1000*ao,a1/2-1000*ao,a1/2-1000*(ao+am),a1/2-1000*(am+ao),-a1/2+1000*(am+ao),-a1/2+1000*(am+ao),-a1/2+1000*ao,-a1/2+1000*ao];
	end


%	temp = input(' Do you want to see each element? y/n [n]:','s');
	temp = 'y' ;
	if isempty(temp),
		temp = 'n';
	end
	
 	if ((( temp == 'y' ) | ( temp == 'Y' )) & (ROC == 0)),

%
% The cuts between elements are not right for curved arrays
%
	if Nn == 2,
		x3 = [0,0];
		y3 = [-1000*a/2,1000*a/2];
	elseif Nn == 3,
		x3 = [-1000*d/2+1000*d/3,-1000*d/2+1000*d/3,d1/2-d1/3,d1/2-d1/3];
		y3 = [-a1/2,a1/2,a1/2,-a1/2];
	elseif Nn == 4,
		x3 = [-d1/2+d1/4,-d1/2+d1/4,0,0,d1/2-d1/4,d1/2-d1/4];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2];
	elseif Nn == 5,
		x3 = [-d1/2+d1/5,-d1/2+d1/5,-d1/2+2*d1/5,-d1/2+2*d1/5,d1/2-2*d1/5,d1/2-2*d1/5,d1/2-d1/5,d1/2-d1/5];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2];
	elseif Nn == 6,
		x3 = [-d1/2+d1/6,-d1/2+d1/6,-d1/2+2*d1/6,-d1/2+2*d1/6,0,0,d1/2-2*d1/6,d1/2-2*d1/6,d1/2-d1/6,d1/2-d1/6];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2];
	elseif Nn == 7,
		x3 = [-d1/2+d1/7,-d1/2+d1/7,-d1/2+2*d1/7,-d1/2+2*d1/7,-d1/2+3*d1/7,-d1/2+3*d1/7,d1/2-3*d1/7,d1/2-3*d1/7,d1/2-2*d1/7,d1/2-2*d1/7,d1/2-d1/7,d1/2-d1/7];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2];
	elseif Nn == 8,
	        x3 = [-d1/2+d1/8,-d1/2+d1/8,-d1/2+2*d1/8,-d1/2+2*d1/8,-d1/2+3*d1/8,-d1/2+3*d1/8,0,0,d1/2-3*d1/8,d1/2-3*d1/8,d1/2-2*d1/8,d1/2-2*d1/8,d1/2-d1/8,d1/2-d1/8];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2];
	elseif Nn == 9,
		x3 = [-d1/2+d1/9,-d1/2+d1/9,-d1/2+2*d1/9,-d1/2+2*d1/9,-d1/2+3*d1/9,-d1/2+3*d1/9,-d1/2+4*d1/9,-d1/2+4*d1/9,d1/2-4*d1/9,d1/2-4*d1/9,d1/2-3*d1/9,d1/2-3*d1/9,d1/2-2*d1/9,d1/2-2*d1/9,d1/2-d1/9,d1/2-d1/9];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2];
	elseif Nn == 10,
		x3 = [-d1/2+d1/10,-d1/2+d1/10,-d1/2+2*d1/10,-d1/2+2*d1/10,-d1/2+3*d1/10,-d1/2+3*d1/10,-d1/2+4*d1/10,-d1/2+4*d1/10,0,0,d1/2-4*d1/10,d1/2-4*d1/10,d1/2-3*d1/10,d1/2-3*d1/10,d1/2-2*d1/10,d1/2-2*d1/10,d1/2-d1/10,d1/2-d1/10];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2];
	elseif Nn == 11,
		x3 = [-d1/2+d1/11,-d1/2+d1/11,-d1/2+2*d1/11,-d1/2+2*d1/11,-d1+3*d1/11,-d1/2+3*d1/11,-d1/2+4*d1/11,-d1/2+4*d1/11,-d1/2+5*d1/11,-d1/2+5*d1/11,d1/2-5*d1/11,d1/2-5*d1/11,d1/2-4*d1/11,d1/2-4*d1/11,d1/2-3*d1/11,d1/2-3*d1/11,d1/2-2*d1/11,d1/2-2*d1/11,d1/2-d1/11,d1/2-d1/11];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2];
	  elseif Nn == 12,
	        x3 = [-d1/2+d1/12,-d1/2+d1/12,-d1/2+2*d1/12,-d1/2+2*d1/12,-d1/2+3*d1/12,-d1/2+3*d1/12,-d1/2+4*d1/12,-d1/2+4*d1/12,-d1/2+5*d1/12,-d1/2+5*d1/12,0,0,d1/2-5*d1/12,d1/2-5*d1/12,d1/2-4*d1/12,d1/2-4*d1/12,d1/2-3*d1/12,d1/2-3*d1/12,d1/2-2*d1/12,d1/2-2*d1/12,d1/2-d1/12,d1/2-d1/12];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2];
	elseif Nn == 13,
		x3 = [-d1/2+d1/13,-d1/2+d1/13,-d1/2+2*d1/13,-d1/2+2*d1/13,-d1/2+3*d1/13,-d1/2+3*d1/13,-d1/2+4*d1/13,-d1/2+4*d1/13,-d1/2+5*d1/13,-d1/2+5*d1/13,-d1/2+6*d1/13,-d1/2+6*d1/13,d1/2-6*d1/13,d1/2-6*d1/13,d1/2-5*d1/13,d1/2-5*d1/13,d1/2-4*d1/13,d1/2-4*d1/13,d1/2-3*d1/13,d1/2-3*d1/13,d1/2-2*d1/13,d1/2-2*d1/13,d1/2-d1/13,d1/2-d1/13];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2];
	elseif Nn == 14,
		x3 = [-d1/2+d1/14,-d1/2+d1/14,-d1/2+2*d1/14,-d1/2+2*d1/14,-d1/2+3*d1/14,-d1/2+3*d1/14,-d1/2+4*d1/14,-d1/2+4*d1/14,-d1/2+5*d1/14,-d1/2+5*d1/14,-d1/2+6*d1/14,-d1/2+6*d1/14,0,0,d1/2-6*d1/14,d1/2-6*d1/14,d1/2-5*d1/14,d1/2-5*d1/14,d1/2-4*d1/14,d1/2-4*d1/14,d1/2-3*d1/14,d1/2-3*d1/14,d1/2-2*d1/14,d1/2-2*d1/14,d1/2-d1/14,d1/2-d1/14];
		y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2];
        elseif Nn == 32 & shape == 0,
	x3 = [-d1/2+d1/32,-d1/2+d1/32,-d1/2+2*d1/32,-d1/2+2*d1/32,-d1/2+3*d1/32,-d1/2+3*d1/32,-d1/2+4*d1/32,-d1/2+4*d1/32,-d1/2+5*d1/32,-d1/2+5*d1/32,-d1/2+6*d1/32,-d1/2+6*d1/32,-d1/2+7*d1/32,-d1/2+7*d1/32,-d1/2+8*d1/32,-d1/2+8*d1/32,-d1/2+9*d1/32,-d1/2+9*d1/32,-d1/2+10*d1/32,-d1/2+10*d1/32,-d1/2+11*d1/32,-d1/2+11*d1/32,-d1/2+12*d1/32,-d1/2+12*d1/32,-d1/2+13*d1/32,-d1/2+13*d1/32,-d1/2+14*d1/32,-d1/2+14*d1/32,-d1/2+15*d1/32,-d1/2+15*d1/32, ...
              0,0,d1/2-15*d1/32,d1/2-15*d1/32,d1/2-14*d1/32,d1/2-14*d1/32,d1/2-13*d1/32,d1/2-13*d1/32,d1/2-12*d1/32,d1/2-12*d1/32,d1/2-11*d1/32,d1/2-11*d1/32,d1/2-10*d1/32,d1/2-10*d1/32,d1/2-9*d1/32,d1/2-9*d1/32,d1/2-8*d1/32,d1/2-8*d1/32,d1/2-7*d1/32,d1/2-7*d1/32,d1/2-6*d1/32,d1/2-6*d1/32,d1/2-5*d1/32,d1/2-5*d1/32,d1/2-4*d1/32,d1/2-4*d1/32,d1/2-3*d1/32,d1/2-3*d1/32,d1/2-2*d1/32,d1/2-2*d1/32,d1/2-d1/32,d1/2-d1/32];
	y3 = [a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2, ...
              -a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2, ...
              a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2, ...
              -a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2, ...
              a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2, ...
              -a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2,a1/2,-a1/2,-a1/2,a1/2, ...
              a1/2,-a1/2];


	end

% plot array outline and element boundaries + x, y view of array:
 	subplot(no_sub,1,1),
	hand=plot(x1,y1,c1,x2,y2,c1,x3,y3,c1, ...
             1000*x_ok, 1000*y_ok,c2,-1000*x_ok,-1000*y_ok,c2, ...
             1000*elem_pts(1,:),1000*elem_pts(2,:),c3);

       else
% plot array outline + x, y view of array: 
  	subplot(no_sub,1,1),
	hand=plot(x1,y1,c1,x2,y2,c1, ...
             1000*x_ok, 1000*y_ok,c2,-1000*x_ok,-1000*y_ok,c2, ...
             1000*elem_pts(1,:),1000*elem_pts(2,:),c3);

   end
        axis([-1000*1.1*d/2,1000*1.1*d/2,-1000*1.1*a/2,1000*1.1*a/2]);
	xlabel('x [mm]')
	ylabel('y [mm]')
	grid
%	axis('square')
        axis('equal')
 	if ROC == 0, 
          if shape > 0
%
% for circular 32 element 1.5D Fresnel array with 5 short-axis elements
%           hatch(hand(4:5), [90 6.8 1]);
          end        
        end

	if ROC == 0,
%
% plot y, z view of array to show elevation focusing
% only if 1.5 D array and curved lenses
%
% JOE 14.04.94
%      if Mm > 1

       if (((Mm == 3 & cond1 & cond3)|(Mm == 5 & cond1 & cond3 & cond5))&no_sub > 1)
	zakse = max(max( max(elem_pts(3,:), abs(min(elem_pts(3,:))))), 1e-4);
	subplot(no_sub,1,no_sub); 	 

	plot(1000*elem_pts(2,:),1000*elem_pts(3,:),c3);
%	title(geometry_text)
	xlabel('y [mm]')
	ylabel('z [mm]')
	grid
	axis([-1000*1.1*a/2,1000*1.1*a/2,-1000*1.1*zakse,1000*1.1*zakse]);
	
      end  %if Mm > 1
	elseif ROC ~= 0 & no_sub > 1,

% SH 19.3.93:
% Curved array curvature: plot x, z view of array:

	
		zakse = max(max(elem_pts(3,:), abs(min(elem_pts(3,:)))));
		subplot(no_sub,1,2);
		plot(1000*elem_pts(1,:), 1000* elem_pts(3,:),c4)
 		xlabel('x [mm]')
		ylabel('z [mm]')
		grid
		axis([-1000*1.1*d/2,1000*1.1*d/2,-1000*1.1*d/2,1000*1.1*d/2]);
		axis('square')
	end

elseif Mm==0 
	subplot(1,1,1),
	plot(1000*elem_pts(1,:),1000*elem_pts(2,:),'go');
	title(geometry_text)
	xlabel('x [mm]')
	ylabel('y [mm]')
	grid
	axis('square')


else	
% JOE 14.02.94 
% General 2D array	
	d1 = d * 1000;
	a1 = a * 1000;
        x1 = [-d1/2,d1/2,d1/2,-d1/2,-d1/2];
	y1 = [-a1/2,-a1/2,a1/2,a1/2,-a1/2];

% Plot array contour and x,y -view of transducer array
%	subplot(no_sub,1,1),
	hand = plot(x1,y1,c6);
	hold on
	
	hand = plot(1000*x_ok, 1000*y_ok,c1,-1000*x_ok,-1000*y_ok,c1, ...
	            1000*elem_pts(1,:),1000*elem_pts(2,:),c5);
	hold off    
%
% give no of active elements
%
	title(['2D array, no of active elements ',num2str(length(find(elem_pts(4,:)>0)))])
	xlabel('x [mm]')
	ylabel('y [mm]')
	grid
	axis([-1000*1.1*d/2,1000*1.1*d/2,-1000*1.1*a/2,1000*1.1*a/2]);
	axis('square')
% Ok for 32 x 32 array of 8 x 8 mm	
%	hatch(hand,[0 6.7 1]); 
%	hatch(hand,[90 10.2 1]);
	
% Skipped in latest version
%	if ROC == 0 & no_sub > 1,
%
% plot y, z view of array to show elevation focusing
%
%
%	zakse = max(max( max(elem_pts(3,:), abs(min(elem_pts(3,:))))), 1e-4);
%	subplot(no_sub,1,no_sub);
%	plot(1000*elem_pts(2,:),1000*elem_pts(3,:),'c*');
%	title(geometry_text);
%	xlabel('y [mm]')
%	ylabel('z [mm]')
%	grid
%	axis([-1000*1.1*a/2,1000*1.1*a/2,-1000*1.1*zakse,1000*1.1*zakse]);
	
%	elseif ROC ~= 0,
% Curved array : plot x, z view of array:

%	end 	%if ROC == 0,

end	%if flagg(2)==1

%	Kari Lervik.	22.10.92.
%--------------------------------------------------------------------------
elseif flagg(2) == 3,
%
% annular, circular transducer
%

%
% plot element boundaries
%	
 	if transducer(18) == 0 | transducer(18)>=4,
% equal area
%
		%radius =[2 4.59 7.20]/1000;
                radius= d/2*sqrt([1:Nn]/Nn);
	elseif transducer(18) == 1,
% equal width

%
		radius = (d/2)*[1:Nn]/Nn;
	else 
%
% plot perimeter only
		radius = (d/2)*ones(Nn);
	end

	nnn = 400; % points in circle plot 
	xxx = -1:2/nnn:1;
 	rx = xxx(ones(1,Nn),:) .* radius(ones(size(xxx)),:)';
 	ry = sqrt(max(0, radius(ones(size(xxx)),:)'.^2 - rx.^2));

        focused = finite(transducer(9)) & transducer(18) <= 9;
	conical = transducer(18) == 10;

        if (focused | conical | no_sub > 1 )
 	   subplot(2,1,1);
        end
	if length(elem_pts) < 30,
		plot(1000*elem_pts(1,:),1000*elem_pts(2,:),c3)
		hold on
      %	elseif length(elem_pts) < 100
   else
		plot(1000*elem_pts(1,:),1000*elem_pts(2,:),c4)	
		hold on
        end
	
	for nnn= 1:length(radius);
		plot(1000*rx(nnn,:),1000*ry(nnn,:),c2,1000*rx(nnn,:),-1000*ry(nnn,:),c2)
		if nnn==1, 
		     hold on
		end
	end

	hold off
        xlabel('x [mm]')
	ylabel('y [mm]')
	grid
	axis([-1000*1.1*d/2,1000*1.1*d/2,-1000*1.1*d/2,1000*1.1*d/2]);
	axis('square')
		
        if (focused | conical | no_sub > 1)
	  subplot(2,1,2)
	  hold off
	  plot(1000*elem_pts(1,:),1000*elem_pts(3,:),'*')
	  xlabel('x [mm]')
	  ylabel('z [mm]')
	  grid
        end
end
return



